<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * UBV\SurUbvBundle\Entity\Aldea
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\AldeaRepository")
 * @ORM\Table(name="aldea", indexes={@ORM\Index(name="fk_aldea_aldea_tipo_idx", columns={"aldea_tipo_id"}), @ORM\Index(name="fk_aldea_ambiente1_idx", columns={"ambiente_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="codigo_sucre_UNIQUE", columns={"codigo_sucre"}), @ORM\UniqueConstraint(name="id_aldea_UNIQUE", columns={"id"})})
 */
class Aldea
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="aldea_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=70)
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="string", length=15, nullable=true)
     */
    protected $codigo_sucre;

    /**
     * @ORM\Column(type="string", length=15, nullable=true)
     */
    protected $codigo_aldea;

    /**
     * @ORM\Column(type="string", length=2)
     */
    protected $estatus;

    /**
     * @ORM\OneToMany(targetEntity="AldeaMallaCurricula", mappedBy="aldea")
     * @ORM\JoinColumn(name="id", referencedColumnName="aldea_id", nullable=false)
     */
    protected $aldeaMallaCurriculas;

    /**
     * @ORM\OneToMany(targetEntity="AldeaPrograma", mappedBy="aldea")
     * @ORM\JoinColumn(name="id", referencedColumnName="aldea_id", nullable=false)
     */
    protected $aldeaProgramas;

    /**
     * @ORM\OneToMany(targetEntity="AldeaTelefono", mappedBy="aldea")
     * @ORM\JoinColumn(name="id", referencedColumnName="aldea_id", nullable=false)
     */
    protected $aldeaTelefonos;

    /**
     * @ORM\OneToMany(targetEntity="Aspirante", mappedBy="aldea")
     * @ORM\JoinColumn(name="id", referencedColumnName="aldea_id", nullable=false)
     */
    protected $aspirantes;
    
    /**
     * @ORM\OneToMany(targetEntity="Candidato", mappedBy="aldea")
     * @ORM\JoinColumn(name="id", referencedColumnName="aldea_id", nullable=false)
     */
    protected $candidatos;

    /**
     * @ORM\OneToMany(targetEntity="DocenteAldea", mappedBy="aldea")
     * @ORM\JoinColumn(name="id", referencedColumnName="aldea_id", nullable=false)
     */
    protected $docenteAldeas;

    /**
     * @ORM\OneToMany(targetEntity="UnidadAdministrativa", mappedBy="aldea")
     * @ORM\JoinColumn(name="id", referencedColumnName="aldea_id", nullable=false)
     */
    protected $unidadAdministrativas;

    /**
     * @ORM\ManyToOne(targetEntity="AldeaTipo", inversedBy="aldeas")
     * @ORM\JoinColumn(name="aldea_tipo_id", referencedColumnName="id", nullable=false)
     */
    protected $aldeaTipo;

    /**
     * @ORM\ManyToOne(targetEntity="Ambiente", inversedBy="aldeas")
     * @ORM\JoinColumn(name="ambiente_id", referencedColumnName="id", nullable=false)
     */
    protected $ambiente;

    public function __construct()
    {
        $this->aldeaMallaCurriculas = new ArrayCollection();
        $this->aldeaProgramas = new ArrayCollection();
        $this->aldeaTelefonos = new ArrayCollection();
        $this->aspirantes = new ArrayCollection();
        $this->docenteAldeas = new ArrayCollection();
        $this->unidadAdministrativas = new ArrayCollection();
        $this->candidatos = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'codigo_sucre', 'codigo_aldea', 'estatus', 'aldea_tipo_id', 'ambiente_id');
    }

    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return Aldea
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set codigo_sucre
     *
     * @param string $codigoSucre
     * @return Aldea
     */
    public function setCodigoSucre($codigoSucre)
    {
        $this->codigo_sucre = $codigoSucre;

        return $this;
    }

    /**
     * Get codigo_sucre
     *
     * @return string
     */
    public function getCodigoSucre()
    {
        return $this->codigo_sucre;
    }

    /**
     * Set codigo_aldea
     *
     * @param string $codigoAldea
     * @return Aldea
     */
    public function setCodigoAldea($codigoAldea)
    {
        $this->codigo_aldea = $codigoAldea;

        return $this;
    }

    /**
     * Get codigo_aldea
     *
     * @return string
     */
    public function getCodigoAldea()
    {
        return $this->codigo_aldea;
    }

    /**
     * Set estatus
     *
     * @param string $estatus
     * @return Aldea
     */
    public function setEstatus($estatus)
    {
        $this->estatus = $estatus;

        return $this;
    }

    /**
     * Get estatus
     *
     * @return string
     */
    public function getEstatus()
    {
        return $this->estatus;
    }

    /**
     * Add aldeaMallaCurriculas
     *
     * @param \UBV\SurUbvBundle\Entity\AldeaMallaCurricula $aldeaMallaCurriculas
     * @return Aldea
     */
    public function addAldeaMallaCurricula(\UBV\SurUbvBundle\Entity\AldeaMallaCurricula $aldeaMallaCurriculas)
    {
        $this->aldeaMallaCurriculas[] = $aldeaMallaCurriculas;

        return $this;
    }

    /**
     * Remove aldeaMallaCurriculas
     *
     * @param \UBV\SurUbvBundle\Entity\AldeaMallaCurricula $aldeaMallaCurriculas
     */
    public function removeAldeaMallaCurricula(\UBV\SurUbvBundle\Entity\AldeaMallaCurricula $aldeaMallaCurriculas)
    {
        $this->aldeaMallaCurriculas->removeElement($aldeaMallaCurriculas);
    }

    /**
     * Get aldeaMallaCurriculas
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getAldeaMallaCurriculas()
    {
        return $this->aldeaMallaCurriculas;
    }

    /**
     * Add aldeaProgramas
     *
     * @param \UBV\SurUbvBundle\Entity\AldeaPrograma $aldeaProgramas
     * @return Aldea
     */
    public function addAldeaPrograma(\UBV\SurUbvBundle\Entity\AldeaPrograma $aldeaProgramas)
    {
        $this->aldeaProgramas[] = $aldeaProgramas;

        return $this;
    }

    /**
     * Remove aldeaProgramas
     *
     * @param \UBV\SurUbvBundle\Entity\AldeaPrograma $aldeaProgramas
     */
    public function removeAldeaPrograma(\UBV\SurUbvBundle\Entity\AldeaPrograma $aldeaProgramas)
    {
        $this->aldeaProgramas->removeElement($aldeaProgramas);
    }

    /**
     * Get aldeaProgramas
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getAldeaProgramas()
    {
        return $this->aldeaProgramas;
    }

    /**
     * Add aldeaTelefonos
     *
     * @param \UBV\SurUbvBundle\Entity\AldeaTelefono $aldeaTelefonos
     * @return Aldea
     */
    public function addAldeaTelefono(\UBV\SurUbvBundle\Entity\AldeaTelefono $aldeaTelefonos)
    {
        $this->aldeaTelefonos[] = $aldeaTelefonos;

        return $this;
    }

    /**
     * Remove aldeaTelefonos
     *
     * @param \UBV\SurUbvBundle\Entity\AldeaTelefono $aldeaTelefonos
     */
    public function removeAldeaTelefono(\UBV\SurUbvBundle\Entity\AldeaTelefono $aldeaTelefonos)
    {
        $this->aldeaTelefonos->removeElement($aldeaTelefonos);
    }

    /**
     * Get aldeaTelefonos
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getAldeaTelefonos()
    {
        return $this->aldeaTelefonos;
    }

    /**
     * Add aspirantes
     *
     * @param \UBV\SurUbvBundle\Entity\Aspirante $aspirantes
     * @return Aldea
     */
    public function addAspirante(\UBV\SurUbvBundle\Entity\Aspirante $aspirantes)
    {
        $this->aspirantes[] = $aspirantes;

        return $this;
    }

    /**
     * Remove aspirantes
     *
     * @param \UBV\SurUbvBundle\Entity\Aspirante $aspirantes
     */
    public function removeAspirante(\UBV\SurUbvBundle\Entity\Aspirante $aspirantes)
    {
        $this->aspirantes->removeElement($aspirantes);
    }

    /**
     * Get aspirantes
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getAspirantes()
    {
        return $this->aspirantes;
    }

    /**
     * Add docenteAldeas
     *
     * @param \UBV\SurUbvBundle\Entity\DocenteAldea $docenteAldeas
     * @return Aldea
     */
    public function addDocenteAldea(\UBV\SurUbvBundle\Entity\DocenteAldea $docenteAldeas)
    {
        $this->docenteAldeas[] = $docenteAldeas;

        return $this;
    }

    /**
     * Remove docenteAldeas
     *
     * @param \UBV\SurUbvBundle\Entity\DocenteAldea $docenteAldeas
     */
    public function removeDocenteAldea(\UBV\SurUbvBundle\Entity\DocenteAldea $docenteAldeas)
    {
        $this->docenteAldeas->removeElement($docenteAldeas);
    }

    /**
     * Get docenteAldeas
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getDocenteAldeas()
    {
        return $this->docenteAldeas;
    }

    /**
     * Add unidadAdministrativas
     *
     * @param \UBV\SurUbvBundle\Entity\UnidadAdministrativa $unidadAdministrativas
     * @return Aldea
     */
    public function addUnidadAdministrativa(\UBV\SurUbvBundle\Entity\UnidadAdministrativa $unidadAdministrativas)
    {
        $this->unidadAdministrativas[] = $unidadAdministrativas;

        return $this;
    }

    /**
     * Remove unidadAdministrativas
     *
     * @param \UBV\SurUbvBundle\Entity\UnidadAdministrativa $unidadAdministrativas
     */
    public function removeUnidadAdministrativa(\UBV\SurUbvBundle\Entity\UnidadAdministrativa $unidadAdministrativas)
    {
        $this->unidadAdministrativas->removeElement($unidadAdministrativas);
    }

    /**
     * Get unidadAdministrativas
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getUnidadAdministrativas()
    {
        return $this->unidadAdministrativas;
    }

    /**
     * Set aldeaTipo
     *
     * @param \UBV\SurUbvBundle\Entity\AldeaTipo $aldeaTipo
     * @return Aldea
     */
    public function setAldeaTipo(\UBV\SurUbvBundle\Entity\AldeaTipo $aldeaTipo)
    {
        $this->aldeaTipo = $aldeaTipo;

        return $this;
    }

    /**
     * Get aldeaTipo
     *
     * @return \UBV\SurUbvBundle\Entity\AldeaTipo
     */
    public function getAldeaTipo()
    {
        return $this->aldeaTipo;
    }

    /**
     * Set ambiente
     *
     * @param \UBV\SurUbvBundle\Entity\Ambiente $ambiente
     * @return Aldea
     */
    public function setAmbiente(\UBV\SurUbvBundle\Entity\Ambiente $ambiente)
    {
        $this->ambiente = $ambiente;

        return $this;
    }

    /**
     * Get ambiente
     *
     * @return \UBV\SurUbvBundle\Entity\Ambiente
     */
    public function getAmbiente()
    {
        return $this->ambiente;
    }
    
    public function __toString()
    {
        return $this->getDescripcion();
    }

    /**
     * Add candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     * @return Aldea
     */
    public function addCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos[] = $candidatos;

        return $this;
    }

    /**
     * Remove candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     */
    public function removeCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos->removeElement($candidatos);
    }

    /**
     * Get candidatos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCandidatos()
    {
        return $this->candidatos;
    }
}
