<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;
/**
 * UBV\SurUbvBundle\Entity\AldeaTipo
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\AldeaTipoRepository")
 * @ORM\Table(name="aldea_tipo", uniqueConstraints={@ORM\UniqueConstraint(name="id_aldea_tipo_UNIQUE", columns={"id"})})
 */
class AldeaTipo
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="aldea_tipo_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=70)
     * @Assert\NotBlank( message= "Por favor introduzca la Descripción de la Aldea")
     *@Assert\Length(
     *      min = 4,
     *      max = 70,
     *      minMessage = "Por favor introduzca un Tipo de Aldea más específico. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un Tipo de Aldea más breve. Máximo {{ limit }} caracteres",
     *)
     */
    protected $descripcion;

    /**
     * @ORM\OneToMany(targetEntity="Aldea", mappedBy="aldeaTipo")
     * @ORM\JoinColumn(name="id", referencedColumnName="aldea_tipo_id", nullable=false)
     */
    protected $aldeas;

    public function __construct()
    {
        $this->aldeas = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion');
    }

    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return AldeaTipo
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Add aldeas
     *
     * @param \UBV\SurUbvBundle\Entity\Aldea $aldeas
     * @return AldeaTipo
     */
    public function addAldea(\UBV\SurUbvBundle\Entity\Aldea $aldeas)
    {
        $this->aldeas[] = $aldeas;

        return $this;
    }

    /**
     * Remove aldeas
     *
     * @param \UBV\SurUbvBundle\Entity\Aldea $aldeas
     */
    public function removeAldea(\UBV\SurUbvBundle\Entity\Aldea $aldeas)
    {
        $this->aldeas->removeElement($aldeas);
    }

    /**
     * Get aldeas
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getAldeas()
    {
        return $this->aldeas;
    }
    
    public function __toString() {
      return $this->getDescripcion();
    }
}
