<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;

use Symfony\Component\Validator\Constraints as Assert;

/**
 * UBV\SurUbvBundle\Entity\Ambiente
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\AmbienteRepository")
 * @ORM\Table(name="ambiente", indexes={@ORM\Index(name="fk_ambiente_parroquia1_idx", columns={"parroquia_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="id_ambiente_UNIQUE", columns={"id"})})
 */
class Ambiente
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="ambiente_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=70, nullable=false)
     * @Assert\NotBlank( message= "Por favor introduzca una Descripción del Nombre del Ambiente")
     * @Assert\Length(
     *      min = 10,
     *      max = 70,
     *      minMessage = "Por favor introduzca un Nombre del Ambiente más específico. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un Nombre del Ambiente más breve. Máximo {{ limit }} caracteres",
     *      
     * )
     * @Assert\NotNull(message="Este Campo no puede Ser Nulo")
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="string", length=6, nullable=false)
     * @Assert\NotBlank( message= "Por favor introduzca el Código del Ambiente")
     * @Assert\Length(
     *      min = 6,
     *      max = 6,
     *      exactMessage = "Por favor introduzca un codigo Válido. debe tener {{ limit }} caracteres",
     *      minMessage = "Por favor introduzca un codigo Válido. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un codigo Válido. Máximo {{ limit }} caracteres",
     *      
     * )
     * @Assert\NotNull(message="Este Campo no puede Ser Nulo")
     */
    protected $codigo;

    /**
     * @ORM\Column(type="text", nullable=false)
     * @Assert\NotBlank( message= "Por favor introduzca una dirección valida")
     * @Assert\Length(
     *      min = 20,
     *      max = 200,
     *      minMessage = "Por favor introduzca una dirección más específica. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca una dirección más breve. Máximo {{ limit }} caracteres",
     *      
     * )
     * @Assert\NotNull(message="Este Campo no puede Ser Nulo")
     */
    protected $direccion;

    /**
     * @ORM\Column(type="text", nullable=true)
     */
    protected $coordenadas_utm_norte;

    /**
     * @ORM\Column(type="text", nullable=true)
     */
    protected $coordenadas_utm_oeste;

    /**
     * @ORM\OneToMany(targetEntity="Aldea", mappedBy="ambiente")
     * @ORM\JoinColumn(name="id", referencedColumnName="ambiente_id", nullable=false)
     */
    protected $aldeas;

    /**
     * @ORM\OneToMany(targetEntity="AmbienteDetalle", mappedBy="ambiente")
     * @ORM\JoinColumn(name="id", referencedColumnName="ambiente_id", nullable=false)
     */
    protected $ambienteDetalles;

    /**
     * @ORM\ManyToOne(targetEntity="Parroquia", inversedBy="ambientes", cascade={"persist", "remove"})
     * @ORM\JoinColumn(name="parroquia_id", referencedColumnName="id", nullable=false)
     */
    protected $parroquia;

    public function __construct()
    {
        $this->aldeas = new ArrayCollection();
        $this->ambienteDetalles = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'codigo', 'direccion', 'coordenadas_utm_norte', 'coordenadas_utm_oeste', 'parroquia_id');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return Ambiente
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set codigo
     *
     * @param string $codigo
     * @return Ambiente
     */
    public function setCodigo($codigo)
    {
        $this->codigo = $codigo;

        return $this;
    }

    /**
     * Get codigo
     *
     * @return string 
     */
    public function getCodigo()
    {
        return $this->codigo;
    }

    /**
     * Set direccion
     *
     * @param string $direccion
     * @return Ambiente
     */
    public function setDireccion($direccion)
    {
        $this->direccion = $direccion;

        return $this;
    }

    /**
     * Get direccion
     *
     * @return string 
     */
    public function getDireccion()
    {
        return $this->direccion;
    }

    /**
     * Set coordenadas_utm_norte
     *
     * @param string $coordenadasUtmNorte
     * @return Ambiente
     */
    public function setCoordenadasUtmNorte($coordenadasUtmNorte)
    {
        $this->coordenadas_utm_norte = $coordenadasUtmNorte;

        return $this;
    }

    /**
     * Get coordenadas_utm_norte
     *
     * @return string 
     */
    public function getCoordenadasUtmNorte()
    {
        return $this->coordenadas_utm_norte;
    }

    /**
     * Set coordenadas_utm_oeste
     *
     * @param string $coordenadasUtmOeste
     * @return Ambiente
     */
    public function setCoordenadasUtmOeste($coordenadasUtmOeste)
    {
        $this->coordenadas_utm_oeste = $coordenadasUtmOeste;

        return $this;
    }

    /**
     * Get coordenadas_utm_oeste
     *
     * @return string 
     */
    public function getCoordenadasUtmOeste()
    {
        return $this->coordenadas_utm_oeste;
    }

    /**
     * Add aldeas
     *
     * @param \UBV\SurUbvBundle\Entity\Aldea $aldeas
     * @return Ambiente
     */
    public function addAldea(\UBV\SurUbvBundle\Entity\Aldea $aldeas)
    {
        $this->aldeas[] = $aldeas;

        return $this;
    }

    /**
     * Remove aldeas
     *
     * @param \UBV\SurUbvBundle\Entity\Aldea $aldeas
     */
    public function removeAldea(\UBV\SurUbvBundle\Entity\Aldea $aldeas)
    {
        $this->aldeas->removeElement($aldeas);
    }

    /**
     * Get aldeas
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getAldeas()
    {
        return $this->aldeas;
    }

    /**
     * Add ambienteDetalles
     *
     * @param \UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalles
     * @return Ambiente
     */
    public function addAmbienteDetalle(\UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalles)
    {
        $this->ambienteDetalles[] = $ambienteDetalles;

        return $this;
    }

    /**
     * Remove ambienteDetalles
     *
     * @param \UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalles
     */
    public function removeAmbienteDetalle(\UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalles)
    {
        $this->ambienteDetalles->removeElement($ambienteDetalles);
    }

    /**
     * Get ambienteDetalles
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getAmbienteDetalles()
    {
        return $this->ambienteDetalles;
    }

    /**
     * Set parroquia
     *
     * @param \UBV\SurUbvBundle\Entity\Parroquia $parroquia
     * @return Ambiente
     */
    public function setParroquia(\UBV\SurUbvBundle\Entity\Parroquia $parroquia)
    {
        $this->parroquia = $parroquia;

        return $this;
    }

    /**
     * Get parroquia
     *
     * @return \UBV\SurUbvBundle\Entity\Parroquia 
     */
    public function getParroquia()
    {
        return $this->parroquia;
    }
    
    public function __toString() {
      return $this->getDescripcion();
    }
}
