<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * UBV\SurUbvBundle\Entity\AmbienteDetalle
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\AmbienteDetalleRepository")
 * @ORM\Table(name="ambiente_detalle", indexes={@ORM\Index(name="fk_ambiente_detalle_ambiente1_idx", columns={"ambiente_id"}), @ORM\Index(name="fk_ambiente_detalle_ambiente_detalle1_idx", columns={"dependencia_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="id_ambiente_detalle_UNIQUE", columns={"id"})})
 */
class AmbienteDetalle
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="ambiente_detalle_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     *@Assert\NotNull(message= "Por favor introduzca un nombre", groups={"Default"})
     *@Assert\NotBlank( message= "Por favor introduzca un nombre Notas Valido", groups={"Default"})
     *@Assert\Length(
     *      min = "2",
     *      max = "70",
     *      minMessage = "El Detalle del Ambiente debe tener ser minimo {{ limit }}",
     *      maxMessage = "El Detalle del Ambiente debe tener no debe exceder de {{ limit }}"
     *)
     *@Assert\Type(type="string", message="El valor  {{ value }} no es valido {{ type }}.")
     *)
     *@Assert\Regex(
     *     pattern="/\d/",
     *     match=false,
     *     message=" El Eje Regional no debe contener numeros")
     * @ORM\Column(type="string", length=70)
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="string", length=2)
     */
    protected $estatus;

    /**
     * @ORM\OneToMany(targetEntity="AmbienteDetalle", mappedBy="ambienteDetalle")
     * @ORM\JoinColumn(name="id", referencedColumnName="dependencia_id", nullable=false)
     */
    protected $ambienteDetalles;

    /**
     * @ORM\OneToMany(targetEntity="AmbienteEspacio", mappedBy="ambienteDetalle")
     * @ORM\JoinColumn(name="id", referencedColumnName="ambiente_detalle_id", nullable=false)
     */
    protected $ambienteEspacios;

    /**
     * @ORM\ManyToOne(targetEntity="Ambiente", inversedBy="ambienteDetalles")
     * @ORM\JoinColumn(name="ambiente_id", referencedColumnName="id", nullable=false)
     */
    protected $ambiente;

    /**
     * @ORM\ManyToOne(targetEntity="AmbienteDetalle", inversedBy="ambienteDetalles")
     * @ORM\JoinColumn(name="dependencia_id", referencedColumnName="id")
     */
    protected $ambienteDetalle;

    public function __construct()
    {
        $this->ambienteDetalles = new ArrayCollection();
        $this->ambienteEspacios = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'estatus', 'ambiente_id', 'dependencia_id');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return AmbienteDetalle
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set estatus
     *
     * @param string $estatus
     * @return AmbienteDetalle
     */
    public function setEstatus($estatus)
    {
        $this->estatus = $estatus;

        return $this;
    }

    /**
     * Get estatus
     *
     * @return string 
     */
    public function getEstatus()
    {
        return $this->estatus;
    }

    /**
     * Add ambienteDetalles
     *
     * @param \UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalles
     * @return AmbienteDetalle
     */
    public function addAmbienteDetalle(\UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalles)
    {
        $this->ambienteDetalles[] = $ambienteDetalles;

        return $this;
    }

    /**
     * Remove ambienteDetalles
     *
     * @param \UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalles
     */
    public function removeAmbienteDetalle(\UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalles)
    {
        $this->ambienteDetalles->removeElement($ambienteDetalles);
    }

    /**
     * Get ambienteDetalles
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getAmbienteDetalles()
    {
        return $this->ambienteDetalles;
    }

    /**
     * Add ambienteEspacios
     *
     * @param \UBV\SurUbvBundle\Entity\AmbienteEspacio $ambienteEspacios
     * @return AmbienteDetalle
     */
    public function addAmbienteEspacio(\UBV\SurUbvBundle\Entity\AmbienteEspacio $ambienteEspacios)
    {
        $this->ambienteEspacios[] = $ambienteEspacios;

        return $this;
    }

    /**
     * Remove ambienteEspacios
     *
     * @param \UBV\SurUbvBundle\Entity\AmbienteEspacio $ambienteEspacios
     */
    public function removeAmbienteEspacio(\UBV\SurUbvBundle\Entity\AmbienteEspacio $ambienteEspacios)
    {
        $this->ambienteEspacios->removeElement($ambienteEspacios);
    }

    /**
     * Get ambienteEspacios
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getAmbienteEspacios()
    {
        return $this->ambienteEspacios;
    }

    /**
     * Set ambiente
     *
     * @param \UBV\SurUbvBundle\Entity\Ambiente $ambiente
     * @return AmbienteDetalle
     */
    public function setAmbiente(\UBV\SurUbvBundle\Entity\Ambiente $ambiente)
    {
        $this->ambiente = $ambiente;

        return $this;
    }

    /**
     * Get ambiente
     *
     * @return \UBV\SurUbvBundle\Entity\Ambiente 
     */
    public function getAmbiente()
    {
        return $this->ambiente;
    }

    /**
     * Set ambienteDetalle
     *
     * @param \UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalle
     * @return AmbienteDetalle
     */
    public function setAmbienteDetalle(\UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalle = null)
    {
        $this->ambienteDetalle = $ambienteDetalle;

        return $this;
    }

    /**
     * Get ambienteDetalle
     *
     * @return \UBV\SurUbvBundle\Entity\AmbienteDetalle 
     */
    public function getAmbienteDetalle()
    {
        return $this->ambienteDetalle;
    }
     public function __toString() {
      return $this->getDescripcion();
    }
}
