<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * UBV\SurUbvBundle\Entity\AmbienteEspacio
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\AmbienteEspacioRepository")
 * @ORM\Table(name="ambiente_espacio", indexes={@ORM\Index(name="fk_ambiente_espacio_tipo_espacio1_idx", columns={"tipo_espacio_id"}), @ORM\Index(name="fk_ambiente_espacio_ambiente_detalle1_idx", columns={"ambiente_detalle_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="id_ambiente_espacio_UNIQUE", columns={"id"})})
 */
class AmbienteEspacio
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="ambiente_espacio_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     *@Assert\NotNull(message= "Por favor introduzca un nombre", groups={"Default"})
     *@Assert\NotBlank( message= "Por favor introduzca un nombre Notas Valido", groups={"Default"})
     *@Assert\Length(
     *      min = "2",
     *      max = "70",
     *      minMessage = "El Espacio debe tener ser minimo {{ limit }}",
     *      maxMessage = "El Espacio  no debe exceder de {{ limit }}"
     *)
     *@Assert\Type(type="string", message="El valor  {{ value }} no es valido {{ type }}.")
     *)
     *@Assert\Regex(
     *     pattern="/\d/",
     *     match=false,
     *     message=" El Espacio no debe contener numeros")
     * @ORM\Column(type="string", length=70)
     */
    protected $descripcion;

    /**
     *@Assert\NotNull(message= "Por favor introduzca un Codigo", groups={"Default"})
     *@Assert\NotBlank( message= "Por favor introduzca un Codigo Notas Valido", groups={"Default"})
     * @Assert\Type(type="string", message="El valor  {{ value }} no es valido {{ type }}.")
     * @ORM\Column(type="integer")
     */
    protected $capacidad;

    /**
     * @ORM\OneToMany(targetEntity="CargaAcademica", mappedBy="ambienteEspacio")
     * @ORM\JoinColumn(name="id", referencedColumnName="ambiente_espacio_id", nullable=false)
     */
    protected $cargaAcademicas;

    /**
     * @ORM\ManyToOne(targetEntity="TipoEspacio", inversedBy="ambienteEspacios")
     * @ORM\JoinColumn(name="tipo_espacio_id", referencedColumnName="id", nullable=false)
     */
    protected $tipoEspacio;

    /**
     * @ORM\ManyToOne(targetEntity="AmbienteDetalle", inversedBy="ambienteEspacios")
     * @ORM\JoinColumn(name="ambiente_detalle_id", referencedColumnName="id", nullable=false)
     */
    protected $ambienteDetalle;

    public function __construct()
    {
        $this->cargaAcademicas = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'capacidad', 'tipo_espacio_id', 'ambiente_detalle_id');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return AmbienteEspacio
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set capacidad
     *
     * @param integer $capacidad
     * @return AmbienteEspacio
     */
    public function setCapacidad($capacidad)
    {
        $this->capacidad = $capacidad;

        return $this;
    }

    /**
     * Get capacidad
     *
     * @return integer 
     */
    public function getCapacidad()
    {
        return $this->capacidad;
    }

    /**
     * Add cargaAcademicas
     *
     * @param \UBV\SurUbvBundle\Entity\CargaAcademica $cargaAcademicas
     * @return AmbienteEspacio
     */
    public function addCargaAcademica(\UBV\SurUbvBundle\Entity\CargaAcademica $cargaAcademicas)
    {
        $this->cargaAcademicas[] = $cargaAcademicas;

        return $this;
    }

    /**
     * Remove cargaAcademicas
     *
     * @param \UBV\SurUbvBundle\Entity\CargaAcademica $cargaAcademicas
     */
    public function removeCargaAcademica(\UBV\SurUbvBundle\Entity\CargaAcademica $cargaAcademicas)
    {
        $this->cargaAcademicas->removeElement($cargaAcademicas);
    }

    /**
     * Get cargaAcademicas
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCargaAcademicas()
    {
        return $this->cargaAcademicas;
    }

    /**
     * Set tipoEspacio
     *
     * @param \UBV\SurUbvBundle\Entity\TipoEspacio $tipoEspacio
     * @return AmbienteEspacio
     */
    public function setTipoEspacio(\UBV\SurUbvBundle\Entity\TipoEspacio $tipoEspacio)
    {
        $this->tipoEspacio = $tipoEspacio;

        return $this;
    }

    /**
     * Get tipoEspacio
     *
     * @return \UBV\SurUbvBundle\Entity\TipoEspacio 
     */
    public function getTipoEspacio()
    {
        return $this->tipoEspacio;
    }

    /**
     * Set ambienteDetalle
     *
     * @param \UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalle
     * @return AmbienteEspacio
     */
    public function setAmbienteDetalle(\UBV\SurUbvBundle\Entity\AmbienteDetalle $ambienteDetalle)
    {
        $this->ambienteDetalle = $ambienteDetalle;

        return $this;
    }

    /**
     * Get ambienteDetalle
     *
     * @return \UBV\SurUbvBundle\Entity\AmbienteDetalle 
     */
    public function getAmbienteDetalle()
    {
        return $this->ambienteDetalle;
    }
}
