<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;
/**
 * UBV\SurUbvBundle\Entity\Aspirante
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\AspiranteRepository")
 * @ORM\Table(name="aspirante", indexes={@ORM\Index(name="fk_aspirante_persona1_idx", columns={"persona_id"}), @ORM\Index(name="fk_aspirante_aspirante_tipo1_idx", columns={"aspirante_tipo_id"}), @ORM\Index(name="fk_aspirante_grado_academico1_idx", columns={"grado_academico_id"}), @ORM\Index(name="fk_aspirante_aldea1_idx", columns={"aldea_id"}), @ORM\Index(name="fk_aspirante_programa1_idx", columns={"programa_id"}), @ORM\Index(name="fk_aspirante_aspirante_estatus1_idx", columns={"aspirante_estatus_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="id_aspirante_UNIQUE", columns={"id"})})
 */
class Aspirante
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="aspirante_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @Assert\NotNull(message= "Por favor introduzca el objetivo de la solicitud", groups={"Default"})
     * @Assert\NotBlank( message= "Por favor introduzca el objetivo de la solicitud", groups={"Default"})
     * 
     * @ORM\Column(type="float", nullable=true)
     */
    protected $promedio_nota;

    /**
     * @Assert\NotBlank( message= "Por favor introduzca el objetivo de la solicitud", groups={"Default"})
     * @ORM\Column(type="date", nullable=false)
     */
    protected $ano_grado;

    /**
     * @Assert\NotBlank( message= "Por favor introduzca el objetivo de la solicitud", groups={"Default"})
     * @ORM\Column(type="string", length=10, nullable=false)
     */
    protected $periodo_asignado;

    /**
     * @Assert\NotNull(message= "Por favor introduzca el objetivo de la solicitud", groups={"Pre-Grado"})
     * @Assert\NotBlank( message= "Por favor introduzca el objetivo de la solicitud", groups={"Pre-Grado"})
     * @ORM\Column(type="string", length=15, nullable=true)
     */
    protected $codigo_opsu;

    /**
     * @ORM\Column(type="string", length=70, nullable=false)
     * @Assert\NotBlank( message= "Por favor introduzca el objetivo de la solicitud", groups={"Default"})
     * )
     */
    protected $institucion_tipo;

    /**
     * @ORM\Column(type="string", length=70, nullable=false)
     * 
     * @Assert\NotBlank( message= "Por favor introduzca el objetivo de la solicitud", groups={"Default"})
     * )
     */
    protected $institucion;

    /**
     * @ORM\Column(type="boolean", nullable=false)
     */
    protected $trabajo;

    /**
     * @ORM\ManyToOne(targetEntity="Persona", inversedBy="aspirantes")
     * @ORM\JoinColumn(name="persona_id", referencedColumnName="id", nullable=false)
     */
    protected $persona;

    /**
     * @ORM\ManyToOne(targetEntity="AspiranteTipo", inversedBy="aspirantes")
     * @ORM\JoinColumn(name="aspirante_tipo_id", referencedColumnName="id", nullable=false)
     */
    protected $aspiranteTipo;

    /**
     * @ORM\ManyToOne(targetEntity="GradoAcademico", inversedBy="aspirantes")
     * @ORM\JoinColumn(name="grado_academico_id", referencedColumnName="id", nullable=false)
     */
    protected $gradoAcademico;

    /**
     * @ORM\ManyToOne(targetEntity="Aldea", inversedBy="aspirantes")
     * @ORM\JoinColumn(name="aldea_id", referencedColumnName="id", nullable=false)
     */
    protected $aldea;

    /**
     * @ORM\ManyToOne(targetEntity="Programa", inversedBy="aspirantes")
     * @ORM\JoinColumn(name="programa_id", referencedColumnName="id", nullable=false)
     */
    protected $programa;

    /**
     * @ORM\ManyToOne(targetEntity="AspiranteEstatus", inversedBy="aspirantes")
     * @ORM\JoinColumn(name="aspirante_estatus_id", referencedColumnName="id", nullable=false)
     */
    protected $aspiranteEstatus;

    public function __construct()
    {
    }

    public function __sleep()
    {
        return array('id', 'promedio_nota', 'año_grado', 'periodo_asignado', 'codigo_opsu', 'persona_id', 'aspirante_tipo_id', 'grado_academico_id', 'aldea_id', 'programa_id', 'aspirante_estatus_id', 'institucion_tipo', 'institucion', 'trabajo');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set promedio_nota
     *
     * @param float $promedioNota
     * @return Aspirante
     */
    public function setPromedioNota($promedioNota)
    {
        $this->promedio_nota = $promedioNota;

        return $this;
    }

    /**
     * Get promedio_nota
     *
     * @return float 
     */
    public function getPromedioNota()
    {
        return $this->promedio_nota;
    }

    /**
     * Set año_grado
     *
     * @param integer $añoGrado
     * @return Aspirante
     */
    public function setAñoGrado($añoGrado)
    {
        $this->año_grado = $añoGrado;

        return $this;
    }

    /**
     * Get año_grado
     *
     * @return integer 
     */
    public function getAñoGrado()
    {
        return $this->año_grado;
    }

    /**
     * Set periodo_asignado
     *
     * @param string $periodoAsignado
     * @return Aspirante
     */
    public function setPeriodoAsignado($periodoAsignado)
    {
        $this->periodo_asignado = $periodoAsignado;

        return $this;
    }

    /**
     * Get periodo_asignado
     *
     * @return string 
     */
    public function getPeriodoAsignado()
    {
        return $this->periodo_asignado;
    }

    /**
     * Set codigo_opsu
     *
     * @param string $codigoOpsu
     * @return Aspirante
     */
    public function setCodigoOpsu($codigoOpsu)
    {
        $this->codigo_opsu = $codigoOpsu;

        return $this;
    }

    /**
     * Get codigo_opsu
     *
     * @return string 
     */
    public function getCodigoOpsu()
    {
        return $this->codigo_opsu;
    }

    /**
     * Set institucion_tipo
     *
     * @param string $institucionTipo
     * @return Aspirante
     */
    public function setInstitucionTipo($institucionTipo)
    {
        $this->institucion_tipo = $institucionTipo;

        return $this;
    }

    /**
     * Get institucion_tipo
     *
     * @return string 
     */
    public function getInstitucionTipo()
    {
        return $this->institucion_tipo;
    }

    /**
     * Set institucion
     *
     * @param string $institucion
     * @return Aspirante
     */
    public function setInstitucion($institucion)
    {
        $this->institucion = $institucion;

        return $this;
    }

    /**
     * Get institucion
     *
     * @return string 
     */
    public function getInstitucion()
    {
        return $this->institucion;
    }

    /**
     * Set trabajo
     *
     * @param boolean $trabajo
     * @return Aspirante
     */
    public function setTrabajo($trabajo)
    {
        $this->trabajo = $trabajo;

        return $this;
    }

    /**
     * Get trabajo
     *
     * @return boolean 
     */
    public function getTrabajo()
    {
        return $this->trabajo;
    }

    /**
     * Set persona
     *
     * @param \UBV\SurUbvBundle\Entity\Persona $persona
     * @return Aspirante
     */
    public function setPersona(\UBV\SurUbvBundle\Entity\Persona $persona = null)
    {
        $this->persona = $persona;

        return $this;
    }

    /**
     * Get persona
     *
     * @return \UBV\SurUbvBundle\Entity\Persona 
     */
    public function getPersona()
    {
        return $this->persona;
    }

    /**
     * Set aspiranteTipo
     *
     * @param \UBV\SurUbvBundle\Entity\AspiranteTipo $aspiranteTipo
     * @return Aspirante
     */
    public function setAspiranteTipo(\UBV\SurUbvBundle\Entity\AspiranteTipo $aspiranteTipo)
    {
        $this->aspiranteTipo = $aspiranteTipo;

        return $this;
    }

    /**
     * Get aspiranteTipo
     *
     * @return \UBV\SurUbvBundle\Entity\AspiranteTipo 
     */
    public function getAspiranteTipo()
    {
        return $this->aspiranteTipo;
    }

    /**
     * Set gradoAcademico
     *
     * @param \UBV\SurUbvBundle\Entity\GradoAcademico $gradoAcademico
     * @return Aspirante
     */
    public function setGradoAcademico(\UBV\SurUbvBundle\Entity\GradoAcademico $gradoAcademico)
    {
        $this->gradoAcademico = $gradoAcademico;

        return $this;
    }

    /**
     * Get gradoAcademico
     *
     * @return \UBV\SurUbvBundle\Entity\GradoAcademico 
     */
    public function getGradoAcademico()
    {
        return $this->gradoAcademico;
    }

    /**
     * Set aldea
     *
     * @param \UBV\SurUbvBundle\Entity\Aldea $aldea
     * @return Aspirante
     */
    public function setAldea(\UBV\SurUbvBundle\Entity\Aldea $aldea)
    {
        $this->aldea = $aldea;

        return $this;
    }

    /**
     * Get aldea
     *
     * @return \UBV\SurUbvBundle\Entity\Aldea 
     */
    public function getAldea()
    {
        return $this->aldea;
    }

    /**
     * Set programa
     *
     * @param \UBV\SurUbvBundle\Entity\Programa $programa
     * @return Aspirante
     */
    public function setPrograma(\UBV\SurUbvBundle\Entity\Programa $programa)
    {
        $this->programa = $programa;

        return $this;
    }

    /**
     * Get programa
     *
     * @return \UBV\SurUbvBundle\Entity\Programa 
     */
    public function getPrograma()
    {
        return $this->programa;
    }

    /**
     * Set aspiranteEstatus
     *
     * @param \UBV\SurUbvBundle\Entity\AspiranteEstatus $aspiranteEstatus
     * @return Aspirante
     */
    public function setAspiranteEstatus(\UBV\SurUbvBundle\Entity\AspiranteEstatus $aspiranteEstatus)
    {
        $this->aspiranteEstatus = $aspiranteEstatus;

        return $this;
    }

    /**
     * Get aspiranteEstatus
     *
     * @return \UBV\SurUbvBundle\Entity\AspiranteEstatus 
     */
    public function getAspiranteEstatus()
    {
        return $this->aspiranteEstatus;
    }

    /**
     * Set ano_grado
     *
     * @param integer $anoGrado
     * @return Aspirante
     */
    public function setAnoGrado($anoGrado)
    {
        $this->ano_grado = $anoGrado;

        return $this;
    }

    /**
     * Get ano_grado
     *
     * @return integer 
     */
    public function getAnoGrado()
    {
        return $this->ano_grado;
    }
}
