<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * UBV\SurUbvBundle\Entity\Banco
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\BancoRepository")
 * @ORM\Table(name="banco", uniqueConstraints={@ORM\UniqueConstraint(name="id_banco_UNIQUE", columns={"id"})})
 */
class Banco
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="banco_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     *@ORM\Column(type="string", length=150)
     *@Assert\NotBlank( message= "Por favor introduzca la Descripción del Banco")
     *@Assert\NotNull(message= "Por favor introduzca la Descripción del Banco", groups={"Default"})
     *@Assert\Length(
     *      min = 5,
     *      max = 150,
     *      minMessage = "Por favor introduzca un Nombre de Banco más específico. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un Nombre de Banco más breve. Máximo {{ limit }} caracteres",
     *)
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="string", length=15, nullable=true)
     * @Assert\NotBlank( message= "Por favor introduzca el Código del Banco")
     * @Assert\Length(
     *      min = 5,
     *      max = 15,
     *      exactMessage = "Por favor introduzca un codigo Válido. debe tener {{ limit }} caracteres", 
     *      minMessage = "Por favor introduzca un codigo Válido. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un codigo Válido. Máximo {{ limit }} caracteres",
     *      
     * )
     * @Assert\NotNull(message="Este Campo no puede Ser Nulo")
     */
    protected $codigo;

    /**
     * @ORM\OneToMany(targetEntity="CuentaBancaria", mappedBy="banco")
     * @ORM\JoinColumn(name="id", referencedColumnName="banco_id", nullable=false)
     */
    protected $cuentaBancarias;

    public function __construct()
    {
        $this->cuentaBancarias = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'codigo');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return Banco
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set codigo
     *
     * @param string $codigo
     * @return Banco
     */
    public function setCodigo($codigo)
    {
        $this->codigo = $codigo;

        return $this;
    }

    /**
     * Get codigo
     *
     * @return string 
     */
    public function getCodigo()
    {
        return $this->codigo;
    }

    /**
     * Add cuentaBancarias
     *
     * @param \UBV\SurUbvBundle\Entity\CuentaBancaria $cuentaBancarias
     * @return Banco
     */
    public function addCuentaBancaria(\UBV\SurUbvBundle\Entity\CuentaBancaria $cuentaBancarias)
    {
        $this->cuentaBancarias[] = $cuentaBancarias;

        return $this;
    }

    /**
     * Remove cuentaBancarias
     *
     * @param \UBV\SurUbvBundle\Entity\CuentaBancaria $cuentaBancarias
     */
    public function removeCuentaBancaria(\UBV\SurUbvBundle\Entity\CuentaBancaria $cuentaBancarias)
    {
        $this->cuentaBancarias->removeElement($cuentaBancarias);
    }

    /**
     * Get cuentaBancarias
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCuentaBancarias()
    {
        return $this->cuentaBancarias;
    }
}
