<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * UBV\SurUbvBundle\Entity\CentroEstudio
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\CentroEstudioRepository")
 * @ORM\Table(name="centro_estudio", indexes={@ORM\Index(name="fk_centro_estudio_area_conocimiento1_idx", columns={"area_conocimiento_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="id_centro_estudio_UNIQUE", columns={"id"})})
 */
class CentroEstudio
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="centro_estudio_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=70)
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="string", length=5)
     */
    protected $codigo;

    /**
     * @ORM\OneToMany(targetEntity="Docente", mappedBy="centroEstudio")
     * @ORM\JoinColumn(name="id", referencedColumnName="centro_estudio_id", nullable=false)
     */
    protected $docentes;

    /**
     * @ORM\OneToMany(targetEntity="Programa", mappedBy="centroEstudio")
     * @ORM\JoinColumn(name="id", referencedColumnName="centro_estudio_id", nullable=false)
     */
    protected $programas;

    /**
     * @ORM\OneToOne(targetEntity="AreaConocimiento", inversedBy="centroEstudio")
     * @ORM\JoinColumn(name="area_conocimiento_id", referencedColumnName="id", nullable=false)
     */
    protected $areaConocimiento;

    public function __construct()
    {
        $this->docentes = new ArrayCollection();
        $this->programas = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'codigo', 'area_conocimiento_id');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return CentroEstudio
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set codigo
     *
     * @param string $codigo
     * @return CentroEstudio
     */
    public function setCodigo($codigo)
    {
        $this->codigo = $codigo;

        return $this;
    }

    /**
     * Get codigo
     *
     * @return string 
     */
    public function getCodigo()
    {
        return $this->codigo;
    }

    /**
     * Add docentes
     *
     * @param \UBV\SurUbvBundle\Entity\Docente $docentes
     * @return CentroEstudio
     */
    public function addDocente(\UBV\SurUbvBundle\Entity\Docente $docentes)
    {
        $this->docentes[] = $docentes;

        return $this;
    }

    /**
     * Remove docentes
     *
     * @param \UBV\SurUbvBundle\Entity\Docente $docentes
     */
    public function removeDocente(\UBV\SurUbvBundle\Entity\Docente $docentes)
    {
        $this->docentes->removeElement($docentes);
    }

    /**
     * Get docentes
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getDocentes()
    {
        return $this->docentes;
    }

    /**
     * Add programas
     *
     * @param \UBV\SurUbvBundle\Entity\Programa $programas
     * @return CentroEstudio
     */
    public function addPrograma(\UBV\SurUbvBundle\Entity\Programa $programas)
    {
        $this->programas[] = $programas;

        return $this;
    }

    /**
     * Remove programas
     *
     * @param \UBV\SurUbvBundle\Entity\Programa $programas
     */
    public function removePrograma(\UBV\SurUbvBundle\Entity\Programa $programas)
    {
        $this->programas->removeElement($programas);
    }

    /**
     * Get programas
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getProgramas()
    {
        return $this->programas;
    }

    /**
     * Set areaConocimiento
     *
     * @param \UBV\SurUbvBundle\Entity\AreaConocimiento $areaConocimiento
     * @return CentroEstudio
     */
    public function setAreaConocimiento(\UBV\SurUbvBundle\Entity\AreaConocimiento $areaConocimiento)
    {
        $this->areaConocimiento = $areaConocimiento;

        return $this;
    }

    /**
     * Get areaConocimiento
     *
     * @return \UBV\SurUbvBundle\Entity\AreaConocimiento 
     */
    public function getAreaConocimiento()
    {
        return $this->areaConocimiento;
    }
}
