<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * UBV\SurUbvBundle\Entity\CorreoTipo
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\CorreoTipoRepository")
 * @ORM\Table(name="correo_tipo", uniqueConstraints={@ORM\UniqueConstraint(name="id_correo_tipo_UNIQUE", columns={"id"})})
 */
class CorreoTipo
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="correo_tipo_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=20)
     *@Assert\NotBlank( message= "Por favor introduzca la Descripción del Correo")
     *@Assert\Length(
     *      min = 5,
     *      max = 20,
     *      minMessage = "Por favor introduzca un Tipo de Correo más específico. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un Tipo de Correo más breve. Máximo {{ limit }} caracteres",
     *)
     */
    protected $descripcion;

    /**
     * @ORM\OneToMany(targetEntity="PersonaCorreo", mappedBy="correoTipo")
     * @ORM\JoinColumn(name="id", referencedColumnName="correo_tipo_id", nullable=false)
     */
    protected $personaCorreos;
    
    /**
     * @ORM\OneToMany(targetEntity="Candidato", mappedBy="correoTipo")
     * @ORM\JoinColumn(name="id", referencedColumnName="correo_tipo_id", nullable=false)
     */
    protected $candidatos;

    public function __construct()
    {
        $this->personaCorreos = new ArrayCollection();
        $this->candidatos = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return CorreoTipo
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Add personaCorreos
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaCorreo $personaCorreos
     * @return CorreoTipo
     */
    public function addPersonaCorreo(\UBV\SurUbvBundle\Entity\PersonaCorreo $personaCorreos)
    {
        $this->personaCorreos[] = $personaCorreos;

        return $this;
    }

    /**
     * Remove personaCorreos
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaCorreo $personaCorreos
     */
    public function removePersonaCorreo(\UBV\SurUbvBundle\Entity\PersonaCorreo $personaCorreos)
    {
        $this->personaCorreos->removeElement($personaCorreos);
    }

    /**
     * Get personaCorreos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPersonaCorreos()
    {
        return $this->personaCorreos;
    }
    
    public function __toString() {
      return $this->getDescripcion();
    }

    /**
     * Add candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     * @return CorreoTipo
     */
    public function addCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos[] = $candidatos;

        return $this;
    }

    /**
     * Remove candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     */
    public function removeCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos->removeElement($candidatos);
    }

    /**
     * Get candidatos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCandidatos()
    {
        return $this->candidatos;
    }
}
