<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * UBV\SurUbvBundle\Entity\CuentaBancariaTipo
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\CuentaBancariaTipoRepository")
 * @ORM\Table(name="cuenta_bancaria_tipo", uniqueConstraints={@ORM\UniqueConstraint(name="id_cuenta_bancaria_tipo_UNIQUE", columns={"id"})})
 */
class CuentaBancariaTipo
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="cuenta_bancaria_tipo_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=15)
     * @Assert\NotBlank( message= "Por favor introduzca una Descripción de la Cuenta Bancaria")
     * @Assert\Length(
     *      min = 7,
     *      max = 70,
     *      minMessage = "Por favor introduzca un tipo de Cuenta valido. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un tipo de Cuenta valido. Máximo {{ limit }} caracteres",
     *      
     * )
     * @Assert\NotNull(message="Este Campo no puede Ser Nulo")
     */
    protected $descripcion;

    /**
     * @ORM\OneToMany(targetEntity="CuentaBancaria", mappedBy="cuentaBancariaTipo")
     * @ORM\JoinColumn(name="id", referencedColumnName="tipo_cuenta_bancaria_id", nullable=false)
     */
    protected $cuentaBancarias;

    public function __construct()
    {
        $this->cuentaBancarias = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return CuentaBancariaTipo
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Add cuentaBancarias
     *
     * @param \UBV\SurUbvBundle\Entity\CuentaBancaria $cuentaBancarias
     * @return CuentaBancariaTipo
     */
    public function addCuentaBancaria(\UBV\SurUbvBundle\Entity\CuentaBancaria $cuentaBancarias)
    {
        $this->cuentaBancarias[] = $cuentaBancarias;

        return $this;
    }

    /**
     * Remove cuentaBancarias
     *
     * @param \UBV\SurUbvBundle\Entity\CuentaBancaria $cuentaBancarias
     */
    public function removeCuentaBancaria(\UBV\SurUbvBundle\Entity\CuentaBancaria $cuentaBancarias)
    {
        $this->cuentaBancarias->removeElement($cuentaBancarias);
    }

    /**
     * Get cuentaBancarias
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCuentaBancarias()
    {
        return $this->cuentaBancarias;
    }
}
