<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;
/**
 * UBV\SurUbvBundle\Entity\DocumentoIdentidadTipo
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\DocumentoIdentidadTipoRepository")
 * @ORM\Table(name="documento_identidad_tipo", uniqueConstraints={@ORM\UniqueConstraint(name="id_documento_identidad_UNIQUE", columns={"id"})})
 */
class DocumentoIdentidadTipo
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="documento_identidad_tipo_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=10, nullable=false)
     * @Assert\NotBlank( message= "Por favor introduzca El Tipo De Documento")
     *@Assert\Length(
     *      min = 4,
     *      max = 10,
     *      minMessage = "Por favor introduzca un Tipo de Documento más específico. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un Tipo de Documento más breve. Máximo {{ limit }} caracteres",
     *)
     */
    protected $descripcion;

				/**
     * @ORM\Column(type="string", length=10, nullable=true)
     */
    protected $codigo;
				
    /**
     * @ORM\OneToMany(targetEntity="PersonaNacionalidad", mappedBy="documentoIdentidadTipo")
     * @ORM\JoinColumn(name="id", referencedColumnName="documento_identidad_tipo_id", nullable=false)
     */
    protected $personaNacionalidads;
    
    /**
     * @ORM\OneToMany(targetEntity="Candidato", mappedBy="documentoIdentidadTipo")
     * @ORM\JoinColumn(name="id", referencedColumnName="documento_identidad_tipo_id", nullable=false)
     */
    protected $candidatos;

    public function __construct()
    {
        $this->candidatos = new ArrayCollection();
        $this->personaNacionalidads = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'codigo');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return DocumentoIdentidadTipo
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Add personaNacionalidads
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaNacionalidad $personaNacionalidads
     * @return DocumentoIdentidadTipo
     */
    public function addPersonaNacionalidad(\UBV\SurUbvBundle\Entity\PersonaNacionalidad $personaNacionalidads)
    {
        $this->personaNacionalidads[] = $personaNacionalidads;

        return $this;
    }

    /**
     * Remove personaNacionalidads
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaNacionalidad $personaNacionalidads
     */
    public function removePersonaNacionalidad(\UBV\SurUbvBundle\Entity\PersonaNacionalidad $personaNacionalidads)
    {
        $this->personaNacionalidads->removeElement($personaNacionalidads);
    }

    /**
     * Get personaNacionalidads
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPersonaNacionalidads()
    {
        return $this->personaNacionalidads;
    }

    /**
     * Set codigo
     *
     * @param string $codigo
     * @return DocumentoIdentidadTipo
     */
    public function setCodigo($codigo)
    {
        $this->codigo = $codigo;

        return $this;
    }

    /**
     * Get codigo
     *
     * @return string 
     */
    public function getCodigo()
    {
        return $this->codigo;
    }
				
				public function __toString()
    {
        return $this->codigo;
    }

    /**
     * Add candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     * @return DocumentoIdentidadTipo
     */
    public function addCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos[] = $candidatos;

        return $this;
    }

    /**
     * Remove candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     */
    public function removeCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos->removeElement($candidatos);
    }

    /**
     * Get candidatos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCandidatos()
    {
        return $this->candidatos;
    }
}
