<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;
/**
 * UBV\SurUbvBundle\Entity\EstadoCivil
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\EstadoCivilRepository")
 * @ORM\Table(name="estado_civil", uniqueConstraints={@ORM\UniqueConstraint(name="id_estado_civil_UNIQUE", columns={"id"})})
 */
class EstadoCivil
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="estado_civil_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=20)
     * @Assert\NotBlank( message= "Por favor introduzca la Descripción del Estado Civil")
     * @Assert\Length(
     *      min = 6,
     *      max = 20,
     *      minMessage = "Por favor introduzca un Tipo de Estado Civil más específico. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un Tipo de Estado Civil más breve. Máximo {{ limit }} caracteres",
     *)
     */
    protected $descripcion;
    
    /**
     * @ORM\Column(type="string", length=5, nullable=false)
     */
    protected $codigo;

    /**
     * @ORM\OneToMany(targetEntity="Persona", mappedBy="estadoCivil")
     * @ORM\JoinColumn(name="id", referencedColumnName="estado_civil_id", nullable=false)
     */
    protected $personas;
    
    /**
     * @ORM\OneToMany(targetEntity="Candidato", mappedBy="estadoCivil")
     * @ORM\JoinColumn(name="id", referencedColumnName="estado_civil_id", nullable=false)
     */
    protected $candidatos;

    public function __construct()
    {
        $this->personas = new ArrayCollection();
        $this->candidatos = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return EstadoCivil
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Add personas
     *
     * @param \UBV\SurUbvBundle\Entity\Persona $personas
     * @return EstadoCivil
     */
    public function addPersona(\UBV\SurUbvBundle\Entity\Persona $personas)
    {
        $this->personas[] = $personas;

        return $this;
    }

    /**
     * Remove personas
     *
     * @param \UBV\SurUbvBundle\Entity\Persona $personas
     */
    public function removePersona(\UBV\SurUbvBundle\Entity\Persona $personas)
    {
        $this->personas->removeElement($personas);
    }

    /**
     * Get personas
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPersonas()
    {
        return $this->personas;
    }
    
    public function __toString() {
      return $this->getDescripcion();
    }

    /**
     * Set codigo
     *
     * @param string $codigo
     * @return EstadoCivil
     */
    public function setCodigo($codigo)
    {
        $this->codigo = $codigo;

        return $this;
    }

    /**
     * Get codigo
     *
     * @return string 
     */
    public function getCodigo()
    {
        return $this->codigo;
    }

    /**
     * Add candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     * @return EstadoCivil
     */
    public function addCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos[] = $candidatos;

        return $this;
    }

    /**
     * Remove candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     */
    public function removeCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos->removeElement($candidatos);
    }

    /**
     * Get candidatos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCandidatos()
    {
        return $this->candidatos;
    }
}
