<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * UBV\SurUbvBundle\Entity\Estudiante
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\EstudianteRepository")
 * @ORM\Table(name="estudiante", indexes={@ORM\Index(name="fk_estudiante_persona1_idx", columns={"persona_id"}), @ORM\Index(name="fk_estudiante_aspirante_tipo1_idx", columns={"aspirante_tipo_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="id_estudiante_UNIQUE", columns={"id"})})
 */
class Estudiante
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="estudiante_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="boolean")
     */
    protected $estatus;

    /**
     * @ORM\OneToMany(targetEntity="EstudianteDetalle", mappedBy="estudiante")
     * @ORM\JoinColumn(name="id", referencedColumnName="estudiante_id", nullable=false)
     */
    protected $estudianteDetalles;

    /**
     * @ORM\OneToMany(targetEntity="Inscripcion", mappedBy="estudiante")
     * @ORM\JoinColumn(name="id", referencedColumnName="estudiante_id", nullable=false)
     */
    protected $inscripcions;

    /**
     * @ORM\OneToOne(targetEntity="Persona", inversedBy="estudiante")
     * @ORM\JoinColumn(name="persona_id", referencedColumnName="id", nullable=false)
     */
    protected $persona;

    /**
     * @ORM\ManyToOne(targetEntity="AspiranteTipo", inversedBy="estudiantes")
     * @ORM\JoinColumn(name="aspirante_tipo_id", referencedColumnName="id", nullable=false)
     */
    protected $aspiranteTipo;

    public function __construct()
    {
        $this->estudianteDetalles = new ArrayCollection();
        $this->inscripcions = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'estatus', 'persona_id', 'aspirante_tipo_id');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set estatus
     *
     * @param boolean $estatus
     * @return Estudiante
     */
    public function setEstatus($estatus)
    {
        $this->estatus = $estatus;

        return $this;
    }

    /**
     * Get estatus
     *
     * @return boolean 
     */
    public function getEstatus()
    {
        return $this->estatus;
    }

    /**
     * Add estudianteDetalles
     *
     * @param \UBV\SurUbvBundle\Entity\EstudianteDetalle $estudianteDetalles
     * @return Estudiante
     */
    public function addEstudianteDetalle(\UBV\SurUbvBundle\Entity\EstudianteDetalle $estudianteDetalles)
    {
        $this->estudianteDetalles[] = $estudianteDetalles;

        return $this;
    }

    /**
     * Remove estudianteDetalles
     *
     * @param \UBV\SurUbvBundle\Entity\EstudianteDetalle $estudianteDetalles
     */
    public function removeEstudianteDetalle(\UBV\SurUbvBundle\Entity\EstudianteDetalle $estudianteDetalles)
    {
        $this->estudianteDetalles->removeElement($estudianteDetalles);
    }

    /**
     * Get estudianteDetalles
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getEstudianteDetalles()
    {
        return $this->estudianteDetalles;
    }

    /**
     * Add inscripcions
     *
     * @param \UBV\SurUbvBundle\Entity\Inscripcion $inscripcions
     * @return Estudiante
     */
    public function addInscripcion(\UBV\SurUbvBundle\Entity\Inscripcion $inscripcions)
    {
        $this->inscripcions[] = $inscripcions;

        return $this;
    }

    /**
     * Remove inscripcions
     *
     * @param \UBV\SurUbvBundle\Entity\Inscripcion $inscripcions
     */
    public function removeInscripcion(\UBV\SurUbvBundle\Entity\Inscripcion $inscripcions)
    {
        $this->inscripcions->removeElement($inscripcions);
    }

    /**
     * Get inscripcions
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getInscripcions()
    {
        return $this->inscripcions;
    }

    /**
     * Set persona
     *
     * @param \UBV\SurUbvBundle\Entity\Persona $persona
     * @return Estudiante
     */
    public function setPersona(\UBV\SurUbvBundle\Entity\Persona $persona)
    {
        $this->persona = $persona;

        return $this;
    }

    /**
     * Get persona
     *
     * @return \UBV\SurUbvBundle\Entity\Persona 
     */
    public function getPersona()
    {
        return $this->persona;
    }

    /**
     * Set aspiranteTipo
     *
     * @param \UBV\SurUbvBundle\Entity\AspiranteTipo $aspiranteTipo
     * @return Estudiante
     */
    public function setAspiranteTipo(\UBV\SurUbvBundle\Entity\AspiranteTipo $aspiranteTipo)
    {
        $this->aspiranteTipo = $aspiranteTipo;

        return $this;
    }

    /**
     * Get aspiranteTipo
     *
     * @return \UBV\SurUbvBundle\Entity\AspiranteTipo 
     */
    public function getAspiranteTipo()
    {
        return $this->aspiranteTipo;
    }
}
