<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * UBV\SurUbvBundle\Entity\Genero
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\GeneroRepository")
 * @ORM\Table(name="genero", uniqueConstraints={@ORM\UniqueConstraint(name="id_genero_UNIQUE", columns={"id"})})
 */
class Genero
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="AUTO")
     * @ORM\SequenceGenerator(sequenceName="genero_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=10, nullable=false)
     * @Assert\NotBlank( message= "Por favor introduzca la Descripción del Genero")
     * @Assert\Length(
     *      min = 7,
     *      max = 10,
     *      minMessage = "Por favor introduzca un Nombre de Genero más específico. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un Nombre de Genero más breve. Máximo {{ limit }} caracteres",
     *)
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="string", length=5,nullable=false)
     */
    protected $codigo;

    /**
     * @ORM\OneToMany(targetEntity="Candidato", mappedBy="genero")
     * @ORM\JoinColumn(name="id", referencedColumnName="genero_id", nullable=false)
     */
    protected $candidatos;
    
    /**
     * @ORM\OneToMany(targetEntity="Persona", mappedBy="genero")
     * @ORM\JoinColumn(name="id", referencedColumnName="genero_id", nullable=false)
     */
    protected $personas;

    public function __construct()
    {
        $this->personas = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion');
    }

    /**
     * Get id
     *
     * @return integer 
     */

    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return Genero
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = strtoupper($descripcion);
        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Add personas
     *
     * @param \UBV\SurUbvBundle\Entity\Persona $personas
     * @return Genero
     */
    public function addPersona(\UBV\SurUbvBundle\Entity\Persona $personas)
    {
        $this->personas[] = $personas;

        return $this;
    }

    /**
     * Remove personas
     *
     * @param \UBV\SurUbvBundle\Entity\Persona $personas
     */
    public function removePersona(\UBV\SurUbvBundle\Entity\Persona $personas)
    {
        $this->personas->removeElement($personas);
    }

    /**
     * Get personas
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getPersonas()
    {
        return $this->personas;
    }
    
    public function __toString() {
      return $this->getDescripcion();
    }

    /**
     * Set codigo
     *
     * @param string $codigo
     * @return Genero
     */
    public function setCodigo($codigo)
    {
        $this->codigo = $codigo;

        return $this;
    }

    /**
     * Get codigo
     *
     * @return string 
     */
    public function getCodigo()
    {
        return $this->codigo;
    }

    /**
     * Add candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     * @return Genero
     */
    public function addCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos[] = $candidatos;

        return $this;
    }

    /**
     * Remove candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     */
    public function removeCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos->removeElement($candidatos);
    }

    /**
     * Get candidatos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCandidatos()
    {
        return $this->candidatos;
    }
}
