<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * UBV\SurUbvBundle\Entity\Municipio
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\MunicipioRepository")
 * @ORM\Table(name="municipio", indexes={@ORM\Index(name="fk_municipio_estado1_idx", columns={"estado_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="id_municipio_UNIQUE", columns={"id"})})
 */
class Municipio
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="municipio_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=45)
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="string", length=6)
     */
    protected $codigo;

    /**
     * @ORM\OneToMany(targetEntity="Parroquia", mappedBy="municipio")
     * @ORM\JoinColumn(name="id", referencedColumnName="municipio_id", nullable=false)
     */
    protected $parroquias;

    /**
     * @ORM\ManyToOne(targetEntity="Estado", inversedBy="municipios", cascade={"persist", "remove"})
     * @ORM\JoinColumn(name="estado_id", referencedColumnName="id", nullable=false)
     */
    protected $estado;

    public function __construct()
    {
        $this->parroquias = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'codigo', 'estado_id');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return Municipio
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set codigo
     *
     * @param string $codigo
     * @return Municipio
     */
    public function setCodigo($codigo)
    {
        $this->codigo = $codigo;

        return $this;
    }

    /**
     * Get codigo
     *
     * @return string 
     */
    public function getCodigo()
    {
        return $this->codigo;
    }

    /**
     * Add parroquias
     *
     * @param \UBV\SurUbvBundle\Entity\Parroquia $parroquias
     * @return Municipio
     */
    public function addParroquia(\UBV\SurUbvBundle\Entity\Parroquia $parroquias)
    {
        $this->parroquias[] = $parroquias;

        return $this;
    }

    /**
     * Remove parroquias
     *
     * @param \UBV\SurUbvBundle\Entity\Parroquia $parroquias
     */
    public function removeParroquia(\UBV\SurUbvBundle\Entity\Parroquia $parroquias)
    {
        $this->parroquias->removeElement($parroquias);
    }

    /**
     * Get parroquias
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getParroquias()
    {
        return $this->parroquias;
    }

    /**
     * Set estado
     *
     * @param \UBV\SurUbvBundle\Entity\Estado $estado
     * @return Municipio
     */
    public function setEstado(\UBV\SurUbvBundle\Entity\Estado $estado)
    {
        $this->estado = $estado;

        return $this;
    }

    /**
     * Get estado
     *
     * @return \UBV\SurUbvBundle\Entity\Estado 
     */
    public function getEstado()
    {
        return $this->estado;
    }
    
    public function __toString() {
      return $this->getDescripcion();
    }
}
