<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * UBV\SurUbvBundle\Entity\Parroquia
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\ParroquiaRepository")
 * @ORM\Table(name="parroquia", indexes={@ORM\Index(name="fk_parroquia_municipio1_idx", columns={"municipio_id"}), @ORM\Index(name="fk_parroquia_eje_municipal1_idx", columns={"eje_municipal_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="id_parroquia_UNIQUE", columns={"id"})})
 */
class Parroquia
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="parroquia_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=50)
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="string", length=6)
     */
    protected $codigo;

    /**
     * @ORM\OneToMany(targetEntity="Ambiente", mappedBy="parroquia")
     * @ORM\JoinColumn(name="id", referencedColumnName="parroquia_id", nullable=false)
     */
    protected $ambientes;

    /**
     * @ORM\OneToMany(targetEntity="DomicilioPersona", mappedBy="parroquia")
     * @ORM\JoinColumn(name="id", referencedColumnName="parroquia_id", nullable=false)
     */
    protected $domicilioPersonas;

    /**
     * @ORM\ManyToOne(targetEntity="Municipio", inversedBy="parroquias")
     * @ORM\JoinColumn(name="municipio_id", referencedColumnName="id", nullable=false)
     */
    protected $municipio;

    /**
     * @ORM\ManyToOne(targetEntity="EjeMunicipal", inversedBy="parroquias")
     * @ORM\JoinColumn(name="eje_municipal_id", referencedColumnName="id", nullable=false)
     */
    protected $ejeMunicipal;

    public function __construct()
    {
        $this->ambientes = new ArrayCollection();
        $this->domicilioPersonas = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'codigo', 'municipio_id', 'eje_municipal_id');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return Parroquia
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set codigo
     *
     * @param string $codigo
     * @return Parroquia
     */
    public function setCodigo($codigo)
    {
        $this->codigo = $codigo;

        return $this;
    }

    /**
     * Get codigo
     *
     * @return string 
     */
    public function getCodigo()
    {
        return $this->codigo;
    }

    /**
     * Add ambientes
     *
     * @param \UBV\SurUbvBundle\Entity\Ambiente $ambientes
     * @return Parroquia
     */
    public function addAmbiente(\UBV\SurUbvBundle\Entity\Ambiente $ambientes)
    {
        $this->ambientes[] = $ambientes;

        return $this;
    }

    /**
     * Remove ambientes
     *
     * @param \UBV\SurUbvBundle\Entity\Ambiente $ambientes
     */
    public function removeAmbiente(\UBV\SurUbvBundle\Entity\Ambiente $ambientes)
    {
        $this->ambientes->removeElement($ambientes);
    }

    /**
     * Get ambientes
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getAmbientes()
    {
        return $this->ambientes;
    }

    /**
     * Add domicilioPersonas
     *
     * @param \UBV\SurUbvBundle\Entity\DomicilioPersona $domicilioPersonas
     * @return Parroquia
     */
    public function addDomicilioPersona(\UBV\SurUbvBundle\Entity\DomicilioPersona $domicilioPersonas)
    {
        $this->domicilioPersonas[] = $domicilioPersonas;

        return $this;
    }

    /**
     * Remove domicilioPersonas
     *
     * @param \UBV\SurUbvBundle\Entity\DomicilioPersona $domicilioPersonas
     */
    public function removeDomicilioPersona(\UBV\SurUbvBundle\Entity\DomicilioPersona $domicilioPersonas)
    {
        $this->domicilioPersonas->removeElement($domicilioPersonas);
    }

    /**
     * Get domicilioPersonas
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getDomicilioPersonas()
    {
        return $this->domicilioPersonas;
    }

    /**
     * Set municipio
     *
     * @param \UBV\SurUbvBundle\Entity\Municipio $municipio
     * @return Parroquia
     */
    public function setMunicipio(\UBV\SurUbvBundle\Entity\Municipio $municipio)
    {
        $this->municipio = $municipio;

        return $this;
    }

    /**
     * Get municipio
     *
     * @return \UBV\SurUbvBundle\Entity\Municipio 
     */
    public function getMunicipio()
    {
        return $this->municipio;
    }

    /**
     * Set ejeMunicipal
     *
     * @param \UBV\SurUbvBundle\Entity\EjeMunicipal $ejeMunicipal
     * @return Parroquia
     */
    public function setEjeMunicipal(\UBV\SurUbvBundle\Entity\EjeMunicipal $ejeMunicipal)
    {
        $this->ejeMunicipal = $ejeMunicipal;

        return $this;
    }

    /**
     * Get ejeMunicipal
     *
     * @return \UBV\SurUbvBundle\Entity\EjeMunicipal 
     */
    public function getEjeMunicipal()
    {
        return $this->ejeMunicipal;
    }
    
    public function __toString()
    {
      return $this->getDescripcion();
    }
}
