<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;
/**
 * UBV\SurUbvBundle\Entity\PeriodoAcademico
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\PeriodoAcademicoRepository")
 * @ORM\Table(name="periodo_academico", uniqueConstraints={@ORM\UniqueConstraint(name="id_periodo_academico_UNIQUE", columns={"id"})})
 */
class PeriodoAcademico
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="periodo_academico_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=70)
     * @Assert\NotBlank( message= "Por favor introduzca la Descripción del Perídodo Académico")
     *@Assert\Length(
     *      min = 6,
     *      max = 70,
     *      minMessage = "Por favor introduzca un Perídodo Académico específico. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un Perídodo Académico más breve. Máximo {{ limit }} caracteres",
     *)
     */
    protected $descripcion;
    
    /**
     * @ORM\Column(type="boolean", nullable=true)
     */
    protected $estatus = false;

    /**
     * @ORM\OneToMany(targetEntity="EstudianteDetalle", mappedBy="periodoAcademico")
     * @ORM\JoinColumn(name="id", referencedColumnName="periodo_academico_id", nullable=false)
     */
    protected $estudianteDetalles;

    /**
     * @ORM\OneToMany(targetEntity="OfertaAcademica", mappedBy="periodoAcademico")
     * @ORM\JoinColumn(name="id", referencedColumnName="periodo_academico_id", nullable=false)
     */
    protected $ofertaAcademicas;
    
    /**
     * @ORM\ManyToOne(targetEntity="PeriodoEstatus", inversedBy="periodoAcademicos")
     * @ORM\JoinColumn(name="periodo_estatus_id", referencedColumnName="id", nullable=false)
     */
    protected $periodoEstatus;
    
    /**
     * @ORM\OneToMany(targetEntity="Candidato", mappedBy="periodoAcademico")
     * @ORM\JoinColumn(name="id", referencedColumnName="periodo_academico_id", nullable=false)
     */
    protected $candidatos;

    public function __construct()
    {
        $this->candidatos = new ArrayCollection();
        $this->estudianteDetalles = new ArrayCollection();
        $this->ofertaAcademicas = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return PeriodoAcademico
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Add estudianteDetalles
     *
     * @param \UBV\SurUbvBundle\Entity\EstudianteDetalle $estudianteDetalles
     * @return PeriodoAcademico
     */
    public function addEstudianteDetalle(\UBV\SurUbvBundle\Entity\EstudianteDetalle $estudianteDetalles)
    {
        $this->estudianteDetalles[] = $estudianteDetalles;

        return $this;
    }

    /**
     * Remove estudianteDetalles
     *
     * @param \UBV\SurUbvBundle\Entity\EstudianteDetalle $estudianteDetalles
     */
    public function removeEstudianteDetalle(\UBV\SurUbvBundle\Entity\EstudianteDetalle $estudianteDetalles)
    {
        $this->estudianteDetalles->removeElement($estudianteDetalles);
    }

    /**
     * Get estudianteDetalles
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getEstudianteDetalles()
    {
        return $this->estudianteDetalles;
    }

    /**
     * Add ofertaAcademicas
     *
     * @param \UBV\SurUbvBundle\Entity\OfertaAcademica $ofertaAcademicas
     * @return PeriodoAcademico
     */
    public function addOfertaAcademica(\UBV\SurUbvBundle\Entity\OfertaAcademica $ofertaAcademicas)
    {
        $this->ofertaAcademicas[] = $ofertaAcademicas;

        return $this;
    }

    /**
     * Remove ofertaAcademicas
     *
     * @param \UBV\SurUbvBundle\Entity\OfertaAcademica $ofertaAcademicas
     */
    public function removeOfertaAcademica(\UBV\SurUbvBundle\Entity\OfertaAcademica $ofertaAcademicas)
    {
        $this->ofertaAcademicas->removeElement($ofertaAcademicas);
    }

    /**
     * Get ofertaAcademicas
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getOfertaAcademicas()
    {
        return $this->ofertaAcademicas;
    }
    
    public function __toString() {
      return $this->getDescripcion();
    }

    /**
     * Set estatus
     *
     * @param boolean $estatus
     * @return PeriodoAcademico
     */
    public function setEstatus($estatus)
    {
        $this->estatus = $estatus;

        return $this;
    }

    /**
     * Get estatus
     *
     * @return boolean 
     */
    public function getEstatus()
    {
        return $this->estatus;
    }

    /**
     * Set periodoEstatus
     *
     * @param \UBV\SurUbvBundle\Entity\PeriodoEstatus $periodoEstatus
     * @return PeriodoAcademico
     */
    public function setPeriodoEstatus(\UBV\SurUbvBundle\Entity\PeriodoEstatus $periodoEstatus)
    {
        $this->periodoEstatus = $periodoEstatus;

        return $this;
    }

    /**
     * Get periodoEstatus
     *
     * @return \UBV\SurUbvBundle\Entity\PeriodoEstatus 
     */
    public function getPeriodoEstatus()
    {
        return $this->periodoEstatus;
    }

    /**
     * Add candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     * @return PeriodoAcademico
     */
    public function addCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos[] = $candidatos;

        return $this;
    }

    /**
     * Remove candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     */
    public function removeCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos->removeElement($candidatos);
    }

    /**
     * Get candidatos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCandidatos()
    {
        return $this->candidatos;
    }
}
