<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;

use FOS\UserBundle\Model\User as BaseUser;

/**
 * UBV\SurUbvBundle\Entity\Persona
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\PersonaRepository")
 * @ORM\Table(name="persona", indexes={@ORM\Index(name="fk_persona_estado_civil1_idx", columns={"estado_civil_id"}), @ORM\Index(name="fk_persona_genero1_idx", columns={"genero_id"}), @ORM\Index(name="fk_persona_pais1_idx", columns={"pais_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="id_persona_UNIQUE", columns={"id"})})
 */
class Persona extends BaseUser
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="persona_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=30, nullable=false)
     * @Assert\NotBlank( message= "Número telefonico Invalido", groups={"Default"})
     * 
     */
    protected $primer_nombre;

    /**
     * @ORM\Column(type="string", length=30, nullable=true)
     */
    protected $segundo_nombre;

    /**
     * @ORM\Column(type="string", length=30, nullable=false)
     */
    protected $primer_apellido;

    /**
     * @ORM\Column(type="string", length=30, nullable=true)
     */
    protected $segundo_apellido;

    /**
     * @ORM\Column(type="date", nullable=false)
     */
    protected $fecha_nacimiento;
		
    /**
     * @ORM\OneToMany(targetEntity="Aspirante", mappedBy="persona", cascade={"persist", "remove"})
     * @ORM\JoinColumn(name="id", referencedColumnName="persona_id", nullable=false)
     * @Assert\Valid
     */
    protected $aspirantes;

    /**
     * @ORM\OneToMany(targetEntity="Deposito", mappedBy="persona", cascade={"persist", "remove"})
     * @ORM\JoinColumn(name="id", referencedColumnName="persona_id", nullable=false)
     * @Assert\Valid()
     */
    protected $depositos;
    
    /**
     * @ORM\ManyToMany(targetEntity="Grupo")
     * @ORM\JoinTable(name="persona_grupo",
     *      joinColumns={@ORM\JoinColumn(name="persona_id", referencedColumnName="id")},
     *      inverseJoinColumns={@ORM\JoinColumn(name="grupo_id", referencedColumnName="id")}
     * )
     * @Assert\Valid()
     */
    protected $groups;
    

    /**
     * @ORM\OneToOne(targetEntity="Docente", mappedBy="persona")
     */
    protected $docente;

    /**
     * @ORM\OneToMany(targetEntity="DomicilioPersona", mappedBy="persona")
     * @ORM\JoinColumn(name="id", referencedColumnName="persona_id", nullable=false)
     */
    protected $domicilioPersonas;

    /**
     * @ORM\OneToOne(targetEntity="Estudiante", mappedBy="persona")
     */
    protected $estudiante;

    /**
     * @ORM\OneToMany(targetEntity="EstudianteDocumento", mappedBy="persona", cascade={"persist", "remove"})
     * @ORM\JoinColumn(name="id", referencedColumnName="persona_id", nullable=false)
     * @Assert\Valid
     */
    protected $estudianteDocumentos;

    /**
     * @ORM\OneToMany(targetEntity="PersonaCorreo", mappedBy="persona", cascade={"persist", "remove"})
     * @ORM\JoinColumn(name="id", referencedColumnName="persona_id", nullable=false)
     * @Assert\Valid
     */
    protected $personaCorreos;

    /**
     * @ORM\OneToMany(targetEntity="PersonaDiscapacidad", mappedBy="persona")
     * @ORM\JoinColumn(name="id", referencedColumnName="persona_id", nullable=false)
     */
    protected $personaDiscapacidads;

    /**
     * @ORM\OneToMany(targetEntity="PersonaEtnia", mappedBy="persona")
     * @ORM\JoinColumn(name="id", referencedColumnName="persona_id", nullable=false)
     */
    protected $personaEtnias;

    /**
     * @ORM\OneToMany(targetEntity="PersonaNacionalidad", mappedBy="persona", cascade={"persist", "remove"})
     * @ORM\JoinColumn(name="id", referencedColumnName="persona_id", nullable=false)
     * @Assert\Valid
     */
    protected $personaNacionalidads;

    /**
     * @ORM\OneToMany(targetEntity="PersonaTelefono", mappedBy="persona", cascade={"persist", "remove"})
     * @ORM\JoinColumn(name="id", referencedColumnName="persona_id", nullable=false)
     * @Assert\Valid
     */
    protected $personaTelefonos;

    /**
     * @ORM\OneToMany(targetEntity="PersonalAdministrativo", mappedBy="persona", cascade={"persist", "remove"})
     * @ORM\JoinColumn(name="id", referencedColumnName="persona_id", nullable=false)
     * @Assert\Valid
     */
    protected $personalAdministrativos;

    /**
     * @ORM\ManyToOne(targetEntity="EstadoCivil", inversedBy="personas")
     * @ORM\JoinColumn(name="estado_civil_id", referencedColumnName="id", nullable=false)
     */
    protected $estadoCivil;

    /**
     * @ORM\ManyToOne(targetEntity="Genero", inversedBy="personas")
     * @ORM\JoinColumn(name="genero_id", referencedColumnName="id", nullable=false)
     */
    protected $genero;

    /**
     * @ORM\ManyToOne(targetEntity="Pais", inversedBy="personas")
     * @ORM\JoinColumn(name="pais_id", referencedColumnName="id", nullable=false)
     */
    protected $pais;

    public function __construct()
    {
        parent::__construct();
        $this->groups = new ArrayCollection();
        $this->aspirantes = new ArrayCollection();
        $this->depositos = new ArrayCollection();
        $this->docentes = new ArrayCollection();
        $this->domicilioPersonas = new ArrayCollection();
        $this->estudiantes = new ArrayCollection();
        $this->estudianteDocumentos = new ArrayCollection();
        $this->personaCorreos = new ArrayCollection();
        $this->personaDiscapacidads = new ArrayCollection();
        $this->personaEtnias = new ArrayCollection();
        $this->personaNacionalidads = new ArrayCollection();
        $this->personaTelefonos = new ArrayCollection();
        $this->personalAdministrativos = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'primer_nombre', 'segundo_nombre', 'primer_apellido', 'segundo_apellido', 'fecha_nacimiento', 'estado_civil_id', 'genero_id', 'pais_id');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set primer_nombre
     *
     * @param string $primerNombre
     * @return Persona
     */
    public function setPrimerNombre($primerNombre)
    {
        $this->primer_nombre = $primerNombre;

        return $this;
    }

    /**
     * Get primer_nombre
     *
     * @return string 
     */
    public function getPrimerNombre()
    {
        return $this->primer_nombre;
    }

    /**
     * Set segundo_nombre
     *
     * @param string $segundoNombre
     * @return Persona
     */
    public function setSegundoNombre($segundoNombre)
    {
        $this->segundo_nombre = $segundoNombre;

        return $this;
    }

    /**
     * Get segundo_nombre
     *
     * @return string 
     */
    public function getSegundoNombre()
    {
        return $this->segundo_nombre;
    }

    /**
     * Set primer_apellido
     *
     * @param string $primerApellido
     * @return Persona
     */
    public function setPrimerApellido($primerApellido)
    {
        $this->primer_apellido = $primerApellido;

        return $this;
    }

    /**
     * Get primer_apellido
     *
     * @return string 
     */
    public function getPrimerApellido()
    {
        return $this->primer_apellido;
    }

    /**
     * Set segundo_apellido
     *
     * @param string $segundoApellido
     * @return Persona
     */
    public function setSegundoApellido($segundoApellido)
    {
        $this->segundo_apellido = $segundoApellido;

        return $this;
    }

    /**
     * Get segundo_apellido
     *
     * @return string 
     */
    public function getSegundoApellido()
    {
        return $this->segundo_apellido;
    }

    /**
     * Set fecha_nacimiento
     *
     * @param \DateTime $fechaNacimiento
     * @return Persona
     */
    public function setFechaNacimiento($fechaNacimiento)
    {
        $this->fecha_nacimiento = $fechaNacimiento;

        return $this;
    }

    /**
     * Get fecha_nacimiento
     *
     * @return \DateTime 
     */
    public function getFechaNacimiento()
    {
        return $this->fecha_nacimiento;
    }

    /**
     * Set estado_civil_id
     *
     * @param integer $estadoCivilId
     * @return Persona
     */
    public function setEstadoCivilId($estadoCivilId)
    {
        $this->estado_civil_id = $estadoCivilId;

        return $this;
    }

    /**
     * Get estado_civil_id
     *
     * @return integer 
     */
    public function getEstadoCivilId()
    {
        return $this->estado_civil_id;
    }

    /**
     * Set genero_id
     *
     * @param integer $generoId
     * @return Persona
     */
    public function setGeneroId($generoId)
    {
        $this->genero_id = $generoId;

        return $this;
    }

    /**
     * Get genero_id
     *
     * @return integer 
     */
    public function getGeneroId()
    {
        return $this->genero_id;
    }

    /**
     * Set pais_id
     *
     * @param integer $paisId
     * @return Persona
     */
    public function setPaisId($paisId)
    {
        $this->pais_id = $paisId;

        return $this;
    }

    /**
     * Get pais_id
     *
     * @return integer 
     */
    public function getPaisId()
    {
        return $this->pais_id;
    }

    /**
     * Set aspirante
     *
     * @param \UBV\SurUbvBundle\Entity\Aspirante $aspirante
     * @return Persona
     */
    public function setAspirante(\UBV\SurUbvBundle\Entity\Aspirante $aspirante = null)
    {
        $this->aspirante = $aspirante;

        return $this;
    }

    /**
     * Get aspirante
     *
     * @return \UBV\SurUbvBundle\Entity\Aspirante 
     */
    public function getAspirante()
    {
        return $this->aspirante;
    }

    /**
     * Add depositos
     *
     * @param \UBV\SurUbvBundle\Entity\Deposito $depositos
     * @return Persona
     */
    public function addDeposito(\UBV\SurUbvBundle\Entity\Deposito $depositos)
    {
        $this->depositos[] = $depositos;

        return $this;
    }

    /**
     * Remove depositos
     *
     * @param \UBV\SurUbvBundle\Entity\Deposito $depositos
     */
    public function removeDeposito(\UBV\SurUbvBundle\Entity\Deposito $depositos)
    {
        $this->depositos->removeElement($depositos);
    }

    /**
     * Get depositos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getDepositos()
    {
        return $this->depositos;
    }

    /**
     * Set docente
     *
     * @param \UBV\SurUbvBundle\Entity\Docente $docente
     * @return Persona
     */
    public function setDocente(\UBV\SurUbvBundle\Entity\Docente $docente = null)
    {
        $this->docente = $docente;

        return $this;
    }

    /**
     * Get docente
     *
     * @return \UBV\SurUbvBundle\Entity\Docente 
     */
    public function getDocente()
    {
        return $this->docente;
    }

    /**
     * Add domicilioPersonas
     *
     * @param \UBV\SurUbvBundle\Entity\DomicilioPersona $domicilioPersonas
     * @return Persona
     */
    public function addDomicilioPersona(\UBV\SurUbvBundle\Entity\DomicilioPersona $domicilioPersonas)
    {
        $this->domicilioPersonas[] = $domicilioPersonas;

        return $this;
    }

    /**
     * Remove domicilioPersonas
     *
     * @param \UBV\SurUbvBundle\Entity\DomicilioPersona $domicilioPersonas
     */
    public function removeDomicilioPersona(\UBV\SurUbvBundle\Entity\DomicilioPersona $domicilioPersonas)
    {
        $this->domicilioPersonas->removeElement($domicilioPersonas);
    }

    /**
     * Get domicilioPersonas
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getDomicilioPersonas()
    {
        return $this->domicilioPersonas;
    }

    /**
     * Set estudiante
     *
     * @param \UBV\SurUbvBundle\Entity\Estudiante $estudiante
     * @return Persona
     */
    public function setEstudiante(\UBV\SurUbvBundle\Entity\Estudiante $estudiante = null)
    {
        $this->estudiante = $estudiante;

        return $this;
    }

    /**
     * Get estudiante
     *
     * @return \UBV\SurUbvBundle\Entity\Estudiante 
     */
    public function getEstudiante()
    {
        return $this->estudiante;
    }

    /**
     * Add estudianteDocumentos
     *
     * @param \UBV\SurUbvBundle\Entity\EstudianteDocumento $estudianteDocumentos
     * @return Persona
     */
    public function addEstudianteDocumento(\UBV\SurUbvBundle\Entity\EstudianteDocumento $estudianteDocumentos)
    {
        $this->estudianteDocumentos[] = $estudianteDocumentos;

        return $this;
    }

    /**
     * Remove estudianteDocumentos
     *
     * @param \UBV\SurUbvBundle\Entity\EstudianteDocumento $estudianteDocumentos
     */
    public function removeEstudianteDocumento(\UBV\SurUbvBundle\Entity\EstudianteDocumento $estudianteDocumentos)
    {
        $this->estudianteDocumentos->removeElement($estudianteDocumentos);
    }

    /**
     * Get estudianteDocumentos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getEstudianteDocumentos()
    {
        return $this->estudianteDocumentos;
    }

    /**
     * Add personaCorreos
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaCorreo $personaCorreos
     * @return Persona
     */
    public function addPersonaCorreo(\UBV\SurUbvBundle\Entity\PersonaCorreo $personaCorreos)
    {
        $this->personaCorreos[] = $personaCorreos;

        return $this;
    }

    /**
     * Remove personaCorreos
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaCorreo $personaCorreos
     */
    public function removePersonaCorreo(\UBV\SurUbvBundle\Entity\PersonaCorreo $personaCorreos)
    {
        $this->personaCorreos->removeElement($personaCorreos);
    }

    /**
     * Get personaCorreos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPersonaCorreos()
    {
        return $this->personaCorreos;
    }

    /**
     * Add personaDiscapacidads
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaDiscapacidad $personaDiscapacidads
     * @return Persona
     */
    public function addPersonaDiscapacidad(\UBV\SurUbvBundle\Entity\PersonaDiscapacidad $personaDiscapacidads)
    {
        $this->personaDiscapacidads[] = $personaDiscapacidads;

        return $this;
    }

    /**
     * Remove personaDiscapacidads
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaDiscapacidad $personaDiscapacidads
     */
    public function removePersonaDiscapacidad(\UBV\SurUbvBundle\Entity\PersonaDiscapacidad $personaDiscapacidads)
    {
        $this->personaDiscapacidads->removeElement($personaDiscapacidads);
    }

    /**
     * Get personaDiscapacidads
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPersonaDiscapacidads()
    {
        return $this->personaDiscapacidads;
    }

    /**
     * Add personaEtnias
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaEtnia $personaEtnias
     * @return Persona
     */
    public function addPersonaEtnia(\UBV\SurUbvBundle\Entity\PersonaEtnia $personaEtnias)
    {
        $this->personaEtnias[] = $personaEtnias;

        return $this;
    }

    /**
     * Remove personaEtnias
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaEtnia $personaEtnias
     */
    public function removePersonaEtnia(\UBV\SurUbvBundle\Entity\PersonaEtnia $personaEtnias)
    {
        $this->personaEtnias->removeElement($personaEtnias);
    }

    /**
     * Get personaEtnias
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPersonaEtnias()
    {
        return $this->personaEtnias;
    }
				
    /**
     * Set personaNacionalidads
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaNacionalidads $personaNacionalidads
     * @return Persona
     */
    public function setPersonaNacionalidads(\UBV\SurUbvBundle\Entity\PersonaNacionalidad $personaNacionalidads = null)
    {
						$this->personaNacionalidads = $personaNacionalidads;
						foreach ($personaNacionalidads as $personaNacionalidad) {
										$personaNacionalidad->Persona($this);
						}
    }

    /**
     * Add personaNacionalidads
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaNacionalidad $personaNacionalidads
     * @return Persona
     */
    public function addPersonaNacionalidad(\UBV\SurUbvBundle\Entity\PersonaNacionalidad $personaNacionalidads)
    {
        $this->personaNacionalidads[] = $personaNacionalidads;

        return $this;
    }

    /**
     * Remove personaNacionalidads
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaNacionalidad $personaNacionalidads
     */
    public function removePersonaNacionalidad(\UBV\SurUbvBundle\Entity\PersonaNacionalidad $personaNacionalidads)
    {
        $this->personaNacionalidads->removeElement($personaNacionalidads);
    }

    /**
     * Get personaNacionalidads
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPersonaNacionalidads()
    {
        return $this->personaNacionalidads;
    }

    /**
     * Add personaTelefonos
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaTelefono $personaTelefonos
     * @return Persona
     */
    public function addPersonaTelefono(\UBV\SurUbvBundle\Entity\PersonaTelefono $personaTelefonos)
    {
        $this->personaTelefonos[] = $personaTelefonos;

        return $this;
    }

    /**
     * Remove personaTelefonos
     *
     * @param \UBV\SurUbvBundle\Entity\PersonaTelefono $personaTelefonos
     */
    public function removePersonaTelefono(\UBV\SurUbvBundle\Entity\PersonaTelefono $personaTelefonos)
    {
        $this->personaTelefonos->removeElement($personaTelefonos);
    }

    /**
     * Get personaTelefonos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPersonaTelefonos()
    {
        return $this->personaTelefonos;
    }

    /**
     * Add personalAdministrativos
     *
     * @param \UBV\SurUbvBundle\Entity\PersonalAdministrativo $personalAdministrativos
     * @return Persona
     */
    public function addPersonalAdministrativo(\UBV\SurUbvBundle\Entity\PersonalAdministrativo $personalAdministrativos)
    {
        $this->personalAdministrativos[] = $personalAdministrativos;

        return $this;
    }

    /**
     * Remove personalAdministrativos
     *
     * @param \UBV\SurUbvBundle\Entity\PersonalAdministrativo $personalAdministrativos
     */
    public function removePersonalAdministrativo(\UBV\SurUbvBundle\Entity\PersonalAdministrativo $personalAdministrativos)
    {
        $this->personalAdministrativos->removeElement($personalAdministrativos);
    }

    /**
     * Get personalAdministrativos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPersonalAdministrativos()
    {
        return $this->personalAdministrativos;
    }

    /**
     * Set estadoCivil
     *
     * @param \UBV\SurUbvBundle\Entity\EstadoCivil $estadoCivil
     * @return Persona
     */
    public function setEstadoCivil(\UBV\SurUbvBundle\Entity\EstadoCivil $estadoCivil)
    {
        $this->estadoCivil = $estadoCivil;

        return $this;
    }

    /**
     * Get estadoCivil
     *
     * @return \UBV\SurUbvBundle\Entity\EstadoCivil 
     */
    public function getEstadoCivil()
    {
        return $this->estadoCivil;
    }

    /**
     * Set genero
     *
     * @param \UBV\SurUbvBundle\Entity\Genero $genero
     * @return Persona
     */
    public function setGenero(\UBV\SurUbvBundle\Entity\Genero $genero)
    {
        $this->genero = $genero;

        return $this;
    }

    /**
     * Get genero
     *
     * @return \UBV\SurUbvBundle\Entity\Genero 
     */
    public function getGenero()
    {
        return $this->genero;
    }

    /**
     * Set pais
     *
     * @param \UBV\SurUbvBundle\Entity\Pais $pais
     * @return Persona
     */
    public function setPais(\UBV\SurUbvBundle\Entity\Pais $pais)
    {
        $this->pais = $pais;

        return $this;
    }

    /**
     * Get pais
     *
     * @return \UBV\SurUbvBundle\Entity\Pais 
     */
    public function getPais()
    {
        return $this->pais;
    }
				
    /**
     * Set aspirantes
     *
     * @param \UBV\SurUbvBundle\Entity\Aspirante $aspirantes
     * @return Persona
     */
    public function setAspirantes(\UBV\SurUbvBundle\Entity\Aspirante $aspirantes = null)
    {
						$this->aspirantes = $aspirantes;
						foreach ($aspirantes as $aspirante) {
										$aspirante->Persona($this);
						}
    }

    /**
     * Add aspirantes
     *
     * @param \UBV\SurUbvBundle\Entity\Aspirante $aspirantes
     * @return Persona
     */
    public function addAspirante(\UBV\SurUbvBundle\Entity\Aspirante $aspirantes)
    {
        $this->aspirantes[] = $aspirantes;

        return $this;
    }

    /**
     * Remove aspirantes
     *
     * @param \UBV\SurUbvBundle\Entity\Aspirante $aspirantes
     */
    public function removeAspirante(\UBV\SurUbvBundle\Entity\Aspirante $aspirantes)
    {
        $this->aspirantes->removeElement($aspirantes);
    }

    /**
     * Get aspirantes
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getAspirantes()
    {
        return $this->aspirantes;
    }
    
    /**
     * Set groups
     *
     * @param Doctrine\Common\Collections\ArrayCollection $groups
     * @return Persona
     */
    
    public function setGroups(\FOS\UserBundle\Model\GroupInterface $groups)
    {
        return $this->addGroup($groups);
    }    

    /**
     * Get groups
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getGroups()
    {
        return $this->groups;
    }

    /**
     * Add groups
     *
     * @param \RF\AutenticacionBundle\Entity\Group $groups
     * @return Usuarios
     */
    /*public function addGroup(\RF\AutenticacionBundle\Entity\Group $groups)
    {
        $this->groups[] = $groups;

        return $this;
    }*/

    /**
     * Remove groups
     *
     * @param \RF\AutenticacionBundle\Entity\Group $groups
     */
    /*public function removeGroup(\RF\AutenticacionBundle\Entity\Group $groups)
    {
        $this->groups->removeElement($groups);
    }*/
}
