<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * UBV\SurUbvBundle\Entity\Programa
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\ProgramaRepository")
 * @ORM\Table(name="programa", indexes={@ORM\Index(name="fk_programa_centro_estudio1_idx", columns={"centro_estudio_id"}), @ORM\Index(name="fk_programa_programa_tipo1_idx", columns={"programa_tipo_id"})}, uniqueConstraints={@ORM\UniqueConstraint(name="id_programa_UNIQUE", columns={"id"}), @ORM\UniqueConstraint(name="codigo_programa_UNIQUE", columns={"codigo"})})
 */
class Programa
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="programa_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=70)
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="string", length=15, nullable=true)
     */
    protected $codigo;

    /**
     * @ORM\OneToMany(targetEntity="AldeaPrograma", mappedBy="programa")
     * @ORM\JoinColumn(name="id", referencedColumnName="programa_id", nullable=false)
     */
    protected $aldeaProgramas;

    /**
     * @ORM\OneToMany(targetEntity="Aspirante", mappedBy="programa")
     * @ORM\JoinColumn(name="id", referencedColumnName="programa_id", nullable=false)
     */
    protected $aspirantes;

    /**
     * @ORM\OneToMany(targetEntity="ComitepfaIntegrante", mappedBy="programa")
     * @ORM\JoinColumn(name="id", referencedColumnName="programa_id", nullable=false)
     */
    protected $comitepfaIntegrantes;

    /**
     * @ORM\OneToMany(targetEntity="Docente", mappedBy="programa")
     * @ORM\JoinColumn(name="id", referencedColumnName="programa_id", nullable=false)
     */
    protected $docentes;

    /**
     * @ORM\OneToMany(targetEntity="LineaInvestigacion", mappedBy="programa")
     * @ORM\JoinColumn(name="id", referencedColumnName="programa_id", nullable=false)
     */
    protected $lineaInvestigacions;

    /**
     * @ORM\OneToMany(targetEntity="MallaCurricular", mappedBy="programa")
     * @ORM\JoinColumn(name="id", referencedColumnName="programa_id", nullable=false)
     */
    protected $mallaCurriculars;

    /**
     * @ORM\ManyToOne(targetEntity="CentroEstudio", inversedBy="programas")
     * @ORM\JoinColumn(name="centro_estudio_id", referencedColumnName="id")
     */
    protected $centroEstudio;
    
    /**
     * @ORM\ManyToOne(targetEntity="NivelAcademico", inversedBy="programas")
     * @ORM\JoinColumn(name="nivel_academico_id", referencedColumnName="id", nullable=false)
     */
    protected $nivelAcademico;
    
    /**
     * @ORM\OneToMany(targetEntity="Candidato", mappedBy="programa")
     * @ORM\JoinColumn(name="id", referencedColumnName="programa_id", nullable=false)
     */
    protected $candidatos;

    /**
     * @ORM\ManyToOne(targetEntity="ProgramaTipo", inversedBy="programas")
     * @ORM\JoinColumn(name="programa_tipo_id", referencedColumnName="id", nullable=false)
     */
    protected $programaTipo;
    
    /**
     * @ORM\ManyToMany(targetEntity="RequisitoInscripcion", mappedBy="programas")
     */
    protected $requisitoInscripcions;

    public function __construct()
    {
        $this->aldeaProgramas = new ArrayCollection();
        $this->candidatos = new ArrayCollection();
        $this->aspirantes = new ArrayCollection();
        $this->comitepfaIntegrantes = new ArrayCollection();
        $this->docentes = new ArrayCollection();
        $this->lineaInvestigacions = new ArrayCollection();
        $this->mallaCurriculars = new ArrayCollection();
        $this->requisitoInscripcions = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'codigo', 'centro_estudio_id', 'programa_tipo_id');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return Programa
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set codigo
     *
     * @param string $codigo
     * @return Programa
     */
    public function setCodigo($codigo)
    {
        $this->codigo = $codigo;

        return $this;
    }

    /**
     * Get codigo
     *
     * @return string 
     */
    public function getCodigo()
    {
        return $this->codigo;
    }

    /**
     * Add aldeaProgramas
     *
     * @param \UBV\SurUbvBundle\Entity\AldeaPrograma $aldeaProgramas
     * @return Programa
     */
    public function addAldeaPrograma(\UBV\SurUbvBundle\Entity\AldeaPrograma $aldeaProgramas)
    {
        $this->aldeaProgramas[] = $aldeaProgramas;

        return $this;
    }

    /**
     * Remove aldeaProgramas
     *
     * @param \UBV\SurUbvBundle\Entity\AldeaPrograma $aldeaProgramas
     */
    public function removeAldeaPrograma(\UBV\SurUbvBundle\Entity\AldeaPrograma $aldeaProgramas)
    {
        $this->aldeaProgramas->removeElement($aldeaProgramas);
    }

    /**
     * Get aldeaProgramas
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getAldeaProgramas()
    {
        return $this->aldeaProgramas;
    }

    /**
     * Add aspirantes
     *
     * @param \UBV\SurUbvBundle\Entity\Aspirante $aspirantes
     * @return Programa
     */
    public function addAspirante(\UBV\SurUbvBundle\Entity\Aspirante $aspirantes)
    {
        $this->aspirantes[] = $aspirantes;

        return $this;
    }

    /**
     * Remove aspirantes
     *
     * @param \UBV\SurUbvBundle\Entity\Aspirante $aspirantes
     */
    public function removeAspirante(\UBV\SurUbvBundle\Entity\Aspirante $aspirantes)
    {
        $this->aspirantes->removeElement($aspirantes);
    }

    /**
     * Get aspirantes
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getAspirantes()
    {
        return $this->aspirantes;
    }

    /**
     * Add comitepfaIntegrantes
     *
     * @param \UBV\SurUbvBundle\Entity\ComitepfaIntegrante $comitepfaIntegrantes
     * @return Programa
     */
    public function addComitepfaIntegrante(\UBV\SurUbvBundle\Entity\ComitepfaIntegrante $comitepfaIntegrantes)
    {
        $this->comitepfaIntegrantes[] = $comitepfaIntegrantes;

        return $this;
    }

    /**
     * Remove comitepfaIntegrantes
     *
     * @param \UBV\SurUbvBundle\Entity\ComitepfaIntegrante $comitepfaIntegrantes
     */
    public function removeComitepfaIntegrante(\UBV\SurUbvBundle\Entity\ComitepfaIntegrante $comitepfaIntegrantes)
    {
        $this->comitepfaIntegrantes->removeElement($comitepfaIntegrantes);
    }

    /**
     * Get comitepfaIntegrantes
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getComitepfaIntegrantes()
    {
        return $this->comitepfaIntegrantes;
    }

    /**
     * Add docentes
     *
     * @param \UBV\SurUbvBundle\Entity\Docente $docentes
     * @return Programa
     */
    public function addDocente(\UBV\SurUbvBundle\Entity\Docente $docentes)
    {
        $this->docentes[] = $docentes;

        return $this;
    }

    /**
     * Remove docentes
     *
     * @param \UBV\SurUbvBundle\Entity\Docente $docentes
     */
    public function removeDocente(\UBV\SurUbvBundle\Entity\Docente $docentes)
    {
        $this->docentes->removeElement($docentes);
    }

    /**
     * Get docentes
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getDocentes()
    {
        return $this->docentes;
    }

    /**
     * Add lineaInvestigacions
     *
     * @param \UBV\SurUbvBundle\Entity\LineaInvestigacion $lineaInvestigacions
     * @return Programa
     */
    public function addLineaInvestigacion(\UBV\SurUbvBundle\Entity\LineaInvestigacion $lineaInvestigacions)
    {
        $this->lineaInvestigacions[] = $lineaInvestigacions;

        return $this;
    }

    /**
     * Remove lineaInvestigacions
     *
     * @param \UBV\SurUbvBundle\Entity\LineaInvestigacion $lineaInvestigacions
     */
    public function removeLineaInvestigacion(\UBV\SurUbvBundle\Entity\LineaInvestigacion $lineaInvestigacions)
    {
        $this->lineaInvestigacions->removeElement($lineaInvestigacions);
    }

    /**
     * Get lineaInvestigacions
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getLineaInvestigacions()
    {
        return $this->lineaInvestigacions;
    }

    /**
     * Add mallaCurriculars
     *
     * @param \UBV\SurUbvBundle\Entity\MallaCurricular $mallaCurriculars
     * @return Programa
     */
    public function addMallaCurricular(\UBV\SurUbvBundle\Entity\MallaCurricular $mallaCurriculars)
    {
        $this->mallaCurriculars[] = $mallaCurriculars;

        return $this;
    }

    /**
     * Remove mallaCurriculars
     *
     * @param \UBV\SurUbvBundle\Entity\MallaCurricular $mallaCurriculars
     */
    public function removeMallaCurricular(\UBV\SurUbvBundle\Entity\MallaCurricular $mallaCurriculars)
    {
        $this->mallaCurriculars->removeElement($mallaCurriculars);
    }

    /**
     * Get mallaCurriculars
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getMallaCurriculars()
    {
        return $this->mallaCurriculars;
    }

    /**
     * Set centroEstudio
     *
     * @param \UBV\SurUbvBundle\Entity\CentroEstudio $centroEstudio
     * @return Programa
     */
    public function setCentroEstudio(\UBV\SurUbvBundle\Entity\CentroEstudio $centroEstudio = null)
    {
        $this->centroEstudio = $centroEstudio;

        return $this;
    }

    /**
     * Get centroEstudio
     *
     * @return \UBV\SurUbvBundle\Entity\CentroEstudio 
     */
    public function getCentroEstudio()
    {
        return $this->centroEstudio;
    }

    /**
     * Set programaTipo
     *
     * @param \UBV\SurUbvBundle\Entity\ProgramaTipo $programaTipo
     * @return Programa
     */
    public function setProgramaTipo(\UBV\SurUbvBundle\Entity\ProgramaTipo $programaTipo)
    {
        $this->programaTipo = $programaTipo;

        return $this;
    }

    /**
     * Get programaTipo
     *
     * @return \UBV\SurUbvBundle\Entity\ProgramaTipo 
     */
    public function getProgramaTipo()
    {
        return $this->programaTipo;
    }
				
    public function __toString(){
            return $this->getDescripcion();
    }

    /**
     * Set nivelAcademico
     *
     * @param \UBV\SurUbvBundle\Entity\NivelAcademico $nivelAcademico
     * @return Programa
     */
    public function setNivelAcademico(\UBV\SurUbvBundle\Entity\NivelAcademico $nivelAcademico)
    {
        $this->nivelAcademico = $nivelAcademico;

        return $this;
    }

    /**
     * Get nivelAcademico
     *
     * @return \UBV\SurUbvBundle\Entity\NivelAcademico 
     */
    public function getNivelAcademico()
    {
        return $this->nivelAcademico;
    }

    /**
     * Add requisitoInscripcions
     *
     * @param \UBV\SurUbvBundle\Entity\RequisitoInscripcion $requisitoInscripcions
     * @return Programa
     */
    public function addRequisitoInscripcion(\UBV\SurUbvBundle\Entity\RequisitoInscripcion $requisitoInscripcions)
    {
        $this->requisitoInscripcions[] = $requisitoInscripcions;

        return $this;
    }

    /**
     * Remove requisitoInscripcions
     *
     * @param \UBV\SurUbvBundle\Entity\RequisitoInscripcion $requisitoInscripcions
     */
    public function removeRequisitoInscripcion(\UBV\SurUbvBundle\Entity\RequisitoInscripcion $requisitoInscripcions)
    {
        $this->requisitoInscripcions->removeElement($requisitoInscripcions);
    }

    /**
     * Get requisitoInscripcions
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getRequisitoInscripcions()
    {
        return $this->requisitoInscripcions;
    }

    /**
     * Add candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     * @return Programa
     */
    public function addCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos[] = $candidatos;

        return $this;
    }

    /**
     * Remove candidatos
     *
     * @param \UBV\SurUbvBundle\Entity\Candidato $candidatos
     */
    public function removeCandidato(\UBV\SurUbvBundle\Entity\Candidato $candidatos)
    {
        $this->candidatos->removeElement($candidatos);
    }

    /**
     * Get candidatos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCandidatos()
    {
        return $this->candidatos;
    }
}
