<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * UBV\SurUbvBundle\Entity\RequisitoInscripcion
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\RequisitoInscripcionRepository")
 * @ORM\Table(name="requisito_inscripcion", uniqueConstraints={@ORM\UniqueConstraint(name="id_requisito_inscripcion_UNIQUE", columns={"id"})})
 */
class RequisitoInscripcion
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="requisito_inscripcion_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=45)
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="boolean")
     */
    protected $estatus;

    /**
     * @ORM\OneToMany(targetEntity="EstudianteDocumento", mappedBy="requisitoInscripcion")
     * @ORM\JoinColumn(name="id", referencedColumnName="requisito_inscripcion_id", nullable=false)
     */
    protected $estudianteDocumentos;

   /**
     * @ORM\ManyToMany(targetEntity="Programa", inversedBy="requisitoInscripcions")
     * @ORM\JoinTable(name="requisito_inscripcion_programa",
     *     joinColumns={@ORM\JoinColumn(name="requisito_inscripcion_id", referencedColumnName="id", nullable=false)},
     *     inverseJoinColumns={@ORM\JoinColumn(name="programa_id", referencedColumnName="id", nullable=false)}
     * )
     */
    protected $programas;

    public function __construct()
    {
        $this->estudianteDocumentos = new ArrayCollection();
        $this->programas = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'estatus');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return RequisitoInscripcion
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set estatus
     *
     * @param boolean $estatus
     * @return RequisitoInscripcion
     */
    public function setEstatus($estatus)
    {
        $this->estatus = $estatus;

        return $this;
    }

    /**
     * Get estatus
     *
     * @return boolean 
     */
    public function getEstatus()
    {
        return $this->estatus;
    }

    /**
     * Add estudianteDocumentos
     *
     * @param \UBV\SurUbvBundle\Entity\EstudianteDocumento $estudianteDocumentos
     * @return RequisitoInscripcion
     */
    public function addEstudianteDocumento(\UBV\SurUbvBundle\Entity\EstudianteDocumento $estudianteDocumentos)
    {
        $this->estudianteDocumentos[] = $estudianteDocumentos;

        return $this;
    }

    /**
     * Remove estudianteDocumentos
     *
     * @param \UBV\SurUbvBundle\Entity\EstudianteDocumento $estudianteDocumentos
     */
    public function removeEstudianteDocumento(\UBV\SurUbvBundle\Entity\EstudianteDocumento $estudianteDocumentos)
    {
        $this->estudianteDocumentos->removeElement($estudianteDocumentos);
    }

    /**
     * Get estudianteDocumentos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getEstudianteDocumentos()
    {
        return $this->estudianteDocumentos;
    }

    /**
     * Add programaTipos
     *
     * @param \UBV\SurUbvBundle\Entity\ProgramaTipo $programaTipos
     * @return RequisitoInscripcion
     */
    public function addProgramaTipo(\UBV\SurUbvBundle\Entity\ProgramaTipo $programaTipos)
    {
        $this->programaTipos[] = $programaTipos;
	return $this;
    }
    
    public function __toString() {
      return $this->getDescripcion();
    }

    /**
     * Add programas
     *
     * @param \UBV\SurUbvBundle\Entity\Programa $programas
     * @return RequisitoInscripcion
     */
    public function addPrograma(\UBV\SurUbvBundle\Entity\Programa $programas)
    {
        $this->programas[] = $programas;
        return $this;
    }

    /**
     * Remove programaTipos
     *
     * @param \UBV\SurUbvBundle\Entity\ProgramaTipo $programaTipos
     */
    public function removeProgramaTipo(\UBV\SurUbvBundle\Entity\ProgramaTipo $programaTipos)
    {
        $this->programaTipos->removeElement($programaTipos);
    }

    /**
     * Get programaTipos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getProgramaTipos()
    {
        return $this->programaTipos;
    }
    
    /**
     * Remove programas
     *
     * @param \UBV\SurUbvBundle\Entity\Programa $programas
     */
    public function removePrograma(\UBV\SurUbvBundle\Entity\Programa $programas)
    {
        $this->programas->removeElement($programas);
    }

    /**
     * Get programas
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getProgramas()
    {
        return $this->programas;
    }
}
