<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * UBV\SurUbvBundle\Entity\TelefonoTipo
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\TelefonoTipoRepository")
 * @ORM\Table(name="telefono_tipo", uniqueConstraints={@ORM\UniqueConstraint(name="id_telefono_tipo_UNIQUE", columns={"id"})})
 */
class TelefonoTipo
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="telefono_tipo_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=10)
     * * @Assert\NotBlank( message= "Por favor introduzca la Descripción del Telefono")
     *@Assert\Length(
     *      min = 4,
     *      max = 10,
     *      minMessage = "Por favor introduzca una Descripción de Telefono  más específico. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca una Descripción de Telefono más breve. Máximo {{ limit }} caracteres",
     *)
     */
    protected $descripcion;

    /**
     * @ORM\OneToMany(targetEntity="TelefonoCodigoArea", mappedBy="telefonoTipo")
     * @ORM\JoinColumn(name="id", referencedColumnName="telefono_tipo_id", nullable=false)
     */
    protected $telefonoCodigoAreas;

    public function __construct()
    {
        $this->telefonoCodigoAreas = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion');
    }

    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return TelefonoTipo
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Add telefonoCodigoAreas
     *
     * @param \UBV\SurUbvBundle\Entity\TelefonoCodigoArea $telefonoCodigoAreas
     * @return TelefonoTipo
     */
    public function addTelefonoCodigoArea(\UBV\SurUbvBundle\Entity\TelefonoCodigoArea $telefonoCodigoAreas)
    {
        $this->telefonoCodigoAreas[] = $telefonoCodigoAreas;

        return $this;
    }

    /**
     * Remove telefonoCodigoAreas
     *
     * @param \UBV\SurUbvBundle\Entity\TelefonoCodigoArea $telefonoCodigoAreas
     */
    public function removeTelefonoCodigoArea(\UBV\SurUbvBundle\Entity\TelefonoCodigoArea $telefonoCodigoAreas)
    {
        $this->telefonoCodigoAreas->removeElement($telefonoCodigoAreas);
    }

    /**
     * Get telefonoCodigoAreas
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getTelefonoCodigoAreas()
    {
        return $this->telefonoCodigoAreas;
    }
    
    public function __toString() {
      return $this->getDescripcion();
    }
}
