<?php

namespace UBV\SurUbvBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;
use Symfony\Component\Validator\Constraints as Assert;
/**
 * UBV\SurUbvBundle\Entity\Tramo
 *
 * @ORM\Entity(repositoryClass="UBV\SurUbvBundle\Entity\TramoRepository")
 * @ORM\Table(name="tramo", uniqueConstraints={@ORM\UniqueConstraint(name="id_tramo_UNIQUE", columns={"id"})})
 */
class Tramo
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="IDENTITY")
     * @ORM\SequenceGenerator(sequenceName="tramo_id_seq", allocationSize=1, initialValue=1)
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=70)
     * @Assert\NotBlank( message= "Por favor introduzca la Descripción del Tramo")
     * @Assert\Length(
     *      min = 5,
     *      max = 10,
     *      minMessage = "Por favor introduzca una Descripción del Tramo más específico. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzcauna Descripción del Tramo más breve. Máximo {{ limit }} caracteres",
     *)
     */
    protected $descripcion;

    /**
     * @ORM\Column(type="string", length=15)
     * * @Assert\NotBlank( message= "Por favor introduzca el Código del Banco")
     * @Assert\Length(
     *      min = 5,
     *      max = 15,
     *      exactMessage = "Por favor introduzca un codigo Válido. debe tener {{ limit }} caracteres",
     *      minMessage = "Por favor introduzca un codigo Válido. Mínimo {{ limit }} caracteres",
     *      maxMessage = "Por favor introduzca un codigo Válido. Máximo {{ limit }} caracteres",
     *      
     * )
     */
    protected $codigo;

    /**
     * @ORM\OneToMany(targetEntity="MallaCurricularDetalle", mappedBy="tramo")
     * @ORM\JoinColumn(name="id", referencedColumnName="tramo_id", nullable=false)
     */
    protected $mallaCurricularDetalles;

    /**
     * @ORM\OneToMany(targetEntity="RequisitoGrado", mappedBy="tramo")
     * @ORM\JoinColumn(name="id", referencedColumnName="tramo_id", nullable=false)
     */
    protected $requisitoGrados;

    /**
     * @ORM\OneToMany(targetEntity="Seccion", mappedBy="tramo")
     * @ORM\JoinColumn(name="id", referencedColumnName="tramo_id", nullable=false)
     */
    protected $seccions;

    public function __construct()
    {
        $this->mallaCurricularDetalles = new ArrayCollection();
        $this->requisitoGrados = new ArrayCollection();
        $this->seccions = new ArrayCollection();
    }

    public function __sleep()
    {
        return array('id', 'descripcion', 'codigo');
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set descripcion
     *
     * @param string $descripcion
     * @return Tramo
     */
    public function setDescripcion($descripcion)
    {
        $this->descripcion = $descripcion;

        return $this;
    }

    /**
     * Get descripcion
     *
     * @return string 
     */
    public function getDescripcion()
    {
        return $this->descripcion;
    }

    /**
     * Set codigo
     *
     * @param string $codigo
     * @return Tramo
     */
    public function setCodigo($codigo)
    {
        $this->codigo = $codigo;

        return $this;
    }

    /**
     * Get codigo
     *
     * @return string 
     */
    public function getCodigo()
    {
        return $this->codigo;
    }

    /**
     * Add mallaCurricularDetalles
     *
     * @param \UBV\SurUbvBundle\Entity\MallaCurricularDetalle $mallaCurricularDetalles
     * @return Tramo
     */
    public function addMallaCurricularDetalle(\UBV\SurUbvBundle\Entity\MallaCurricularDetalle $mallaCurricularDetalles)
    {
        $this->mallaCurricularDetalles[] = $mallaCurricularDetalles;

        return $this;
    }

    /**
     * Remove mallaCurricularDetalles
     *
     * @param \UBV\SurUbvBundle\Entity\MallaCurricularDetalle $mallaCurricularDetalles
     */
    public function removeMallaCurricularDetalle(\UBV\SurUbvBundle\Entity\MallaCurricularDetalle $mallaCurricularDetalles)
    {
        $this->mallaCurricularDetalles->removeElement($mallaCurricularDetalles);
    }

    /**
     * Get mallaCurricularDetalles
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getMallaCurricularDetalles()
    {
        return $this->mallaCurricularDetalles;
    }

    /**
     * Add requisitoGrados
     *
     * @param \UBV\SurUbvBundle\Entity\RequisitoGrado $requisitoGrados
     * @return Tramo
     */
    public function addRequisitoGrado(\UBV\SurUbvBundle\Entity\RequisitoGrado $requisitoGrados)
    {
        $this->requisitoGrados[] = $requisitoGrados;

        return $this;
    }

    /**
     * Remove requisitoGrados
     *
     * @param \UBV\SurUbvBundle\Entity\RequisitoGrado $requisitoGrados
     */
    public function removeRequisitoGrado(\UBV\SurUbvBundle\Entity\RequisitoGrado $requisitoGrados)
    {
        $this->requisitoGrados->removeElement($requisitoGrados);
    }

    /**
     * Get requisitoGrados
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getRequisitoGrados()
    {
        return $this->requisitoGrados;
    }

    /**
     * Add seccions
     *
     * @param \UBV\SurUbvBundle\Entity\Seccion $seccions
     * @return Tramo
     */
    public function addSeccion(\UBV\SurUbvBundle\Entity\Seccion $seccions)
    {
        $this->seccions[] = $seccions;

        return $this;
    }

    /**
     * Remove seccions
     *
     * @param \UBV\SurUbvBundle\Entity\Seccion $seccions
     */
    public function removeSeccion(\UBV\SurUbvBundle\Entity\Seccion $seccions)
    {
        $this->seccions->removeElement($seccions);
    }

    /**
     * Get seccions
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getSeccions()
    {
        return $this->seccions;
    }
}
